@@ -3,24 +3,23 @@
 '''
 @author: M. Bernt
 
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
-
 get gene orders from a set of gb-files
 @author: M. Bernt
 @todo if no file is given -> take from db
 '''
 
-from __future__ import print_function
-from optparse import OptionParser
-from os.path import isfile, isdir, exists
-# import pickle
-from os import listdir
-import sys
 
-from mitos.gb import gbfromfile
+import pickle
+import sys
+from optparse import OptionParser
+from os import listdir
+from os.path import exists, isdir, isfile
+
+from mitos import mito
 from mitos.bedfile import bedfromfile
-import mitos.mito as mito
+from mitos.gb import gbfromfile
+from mitos.trna.arwenscan import arwenfromdb
+from mitos.trna.trnascan import trnascanfromdb
 
 usage = "usage: %prog [options] gbfiles"
 parser = OptionParser(usage)
@@ -69,7 +68,7 @@ if len(files) == 0:
     sys.exit()
 
 # outfile and outdir given ?
-if options.outfile == None:
+if options.outfile is None:
     ohandle = sys.stdout
 else:
     ohandle = open(options.outfile, "w")
@@ -100,9 +99,9 @@ if options.ignore:
 def deltrnafeat_ovlprotrrna(gb, tf, threshold):
     """
     compute a subset of features in tf which have
-        - names in trna 
+        - names in trna
         - cummulative overlap (fraction) with features from gb <= threshold
-    return subset array 
+    return subset array
     """
 
     global trna
@@ -121,8 +120,8 @@ def deltrnafeat_ovlprotrrna(gb, tf, threshold):
             cap, cup = tf.features[i].capcup(g, gb.circular, gb.size)
             capsum += cap
 
-        l = tf.features[i].len(True, gb.size)
-        if float(capsum) / float(l) > threshold:
+        length = tf.features[i].len(True, gb.size)
+        if float(capsum) / float(length) > threshold:
             del tf.features[i]
 
     return tf
@@ -169,8 +168,8 @@ def correct_multiplicity(gb, arwen, trnascan, threshold):
                 pairs = []
                 for i in arwenm[m]:
                     for j in trnascanm[m]:
-                        if trnascan.features[ j ].overlap( arwen.features[ i ], gb.size ) >= threshold and \
-                                trnascan.features[j].name == arwen.features[i].name:
+                        if (trnascan.features[j].overlap(arwen.features[i], gb.size) >= threshold
+                                and trnascan.features[j].name == arwen.features[i].name):
                             pairs.append((i, j))
                 if len(pairs) == 1:
                     gb.features.append(trnascan.features[pairs[0][1]])
@@ -240,17 +239,17 @@ def correct_names(gb, arwen, trnascan, threshold):
                 maxtf = tf
 #        print gb.features[i], maxtf, maxt
 
-        if maxaf != None and gb.features[i].name != maxaf.name:
-            if not gb.features[i].name in rename:
+        if maxaf is not None and gb.features[i].name != maxaf.name:
+            if gb.features[i].name not in rename:
                 rename[gb.features[i].name] = {}
-            if not maxaf.name in rename[gb.features[i].name]:
+            if maxaf.name not in rename[gb.features[i].name]:
                 rename[gb.features[i].name][maxaf.name] = 0
             rename[gb.features[i].name][maxaf.name] += 1
 
-        if maxtf != None and gb.features[i].name != maxtf.name:
-            if not gb.features[i].name in rename:
+        if maxtf is not None and gb.features[i].name != maxtf.name:
+            if gb.features[i].name not in rename:
                 rename[gb.features[i].name] = {}
-            if not maxtf.name in rename[gb.features[i].name]:
+            if maxtf.name not in rename[gb.features[i].name]:
                 rename[gb.features[i].name][maxtf.name] = 0
             rename[gb.features[i].name][maxtf.name] += 1
 
@@ -273,7 +272,7 @@ def correct_names(gb, arwen, trnascan, threshold):
         memory = set()
         n = gb.features[i].name
         while 1:
-            if not n in rename:
+            if n not in rename:
                 break
             if len(rename[n]) != 1:
                 break
@@ -317,17 +316,17 @@ def correct_signs(gb, arwen, trnascan, threshold):
                     maxt = o
                 maxtf = tf
 
-        if (maxaf == None and maxtf != None and maxtf.name == gb.features[i].name):
+        if (maxaf is None and maxtf is not None and maxtf.name == gb.features[i].name):
             if gb.features[i].strand != maxtf.strand:
                 sys.stderr.write("%s correct strand %s %d -> %d\n" %
                                  (gb.accession, gb.features[i].name, gb.features[i].strand, maxtf.strand))
                 gb.features[i].strand = maxtf.strand
-        elif (maxtf == None and maxaf != None and maxaf.name == gb.features[i].name):
+        elif (maxtf is None and maxaf is not None and maxaf.name == gb.features[i].name):
             if gb.features[i].strand != maxaf.strand:
                 sys.stderr.write("%s correct strand %s %d -> %d\n" %
                                  (gb.accession, gb.features[i].name, gb.features[i].strand, maxaf.strand))
                 gb.features[i].strand = maxaf.strand
-        elif (maxaf != None and maxtf != None and maxaf.name == gb.features[i].name and maxtf.name == gb.features[i].name):
+        elif (maxaf is not None and maxtf is not None and maxaf.name == gb.features[i].name and maxtf.name == gb.features[i].name):
             if gb.features[i].strand != maxaf.strand and maxaf.strand == maxtf.strand:
                 sys.stderr.write("%s correct strand %s %d -> %d\n" %
                                  (gb.accession, gb.features[i].name, gb.features[i].strand, maxaf.strand))
@@ -378,26 +377,26 @@ for arg in files:
 #            continue
 #        print "gb",g
 
-# TODO    if options.improve:
-#         get arwen and trnascan results from db
-#        if( exists( "/tmp/%s.arw"%gb.accession ) ):
-#            f = open("/tmp/%s.arw"%gb.accession, "r")
-#            arwen = pickle.load(f)
-#            f.close()
-#        else:
-        # # TODO arwen = arwenfromdb( gb.accession )
-#            f = open("/tmp/%s.arw"%gb.accession, "w")
-#            pickle.dump(arwen, f)
-#            f.close
-#        if( exists( "/tmp/%s.tsc"%gb.accession ) ):
-#            f = open("/tmp/%s.tsc"%gb.accession, "r")
-#            trnascan = pickle.load(f)
-#            f.close()
-#        else:
-        # # TODO trnascan = trnascanfromdb( gb.accession )
-#            f = open("/tmp/%s.tsc"%gb.accession, "w")
-#            pickle.dump(trnascan, f)
-#            f.close
+        # TODO if options.improve:
+        # get arwen and trnascan results from db
+        if exists("/tmp/%s.arw" % gb.accession):
+            f = open("/tmp/%s.arw" % gb.accession, "r")
+            arwen = pickle.load(f)
+            f.close()
+        else:
+            arwen = arwenfromdb(gb.accession)
+            f = open("/tmp/%s.arw" % gb.accession, "w")
+            pickle.dump(arwen, f)
+            f.close
+        if exists("/tmp/%s.tsc" % gb.accession):
+            f = open("/tmp/%s.tsc" % gb.accession, "r")
+            trnascan = pickle.load(f)
+            f.close()
+        else:
+            trnascan = trnascanfromdb(gb.accession)
+            f = open("/tmp/%s.tsc" % gb.accession, "w")
+            pickle.dump(trnascan, f)
+            f.close
 
         # delete trnas that
         # - dont have a standard name, or
@@ -421,13 +420,12 @@ for arg in files:
     go = gb.geneorder(
         atypes=["gene", "rRNA", "tRNA", "rep_origin"], fnames=options.ignore)
 
-    if options.mad == True:
+    if options.mad is True:
         go = unique(go)
 
     cnt = {}
     for i in genes:
         cnt[i] = 0
-
     cnterr = False
     for g in go:
         if g[0] == '-':
@@ -435,13 +433,13 @@ for arg in files:
         else:
             x = g
 
-        if not x in genes:
+        if x not in genes:
             sys.stderr.write("%s unknown %s\n" % (gb.accession, x))
             cnterr = True
         else:
             try:
                 cnt[x] += 1
-            except:
+            except KeyError:
                 cnt[x] = 1
     for g in cnt:
         if cnt[g] != 1:
@@ -473,5 +471,5 @@ for arg in files:
     #    print r.authors, r.journal, r.title
 
 # outfile and outdir given ?
-if options.outfile != None:
+if options.outfile is not None:
     ohandle.close()
