@@ -1,13 +1,7 @@
 '''
 @author: maze
-
-This is a confidential release. Do not redistribute without
-permission of the author (bernt@informatik.uni-leipzig.de).
 '''
 
-from Bio.Data import CodonTable
-import Bio.Blast.NCBIXML
-
 import copy
 import glob
 import logging
@@ -15,14 +9,15 @@ import math
 import os
 import sys
 
-from .. import bedfile
-from .. import feature
-from ..gb import gbfromfile
-from ..mito import type_from_name
-from ..mergefeature import _copy_part
-from ..sequence import sequences_fromfile
-from .. import update
-from .. import trna
+import Bio.Blast.NCBIXML
+from Bio.Data import CodonTable
+
+from mitos import feature
+from mitos import trna
+from mitos import update
+from mitos.mergefeature import _copy_part
+from mitos.mito import type_from_name
+from mitos.sequence import sequences_fromfile
 
 
 class UpdateZeroScore(Exception):
@@ -321,7 +316,7 @@ def blast(fastafiles, offsets, prot, cr, filepath, refdir,
         # correct the idx and the values for the offset
         logging.debug("offset %d" % (offsets[i]))
         for n in oidx:  # names
-            if not n in idx:
+            if n not in idx:
                 idx[n] = dict()
 
             for of in oidx[n]:  # frames
@@ -331,7 +326,7 @@ def blast(fastafiles, offsets, prot, cr, filepath, refdir,
                     f = math.copysign(
                         ((abs(of) - 1) + (offsets[i] % 3)) % 3 + 1, of)
 
-                if not f in idx[n]:
+                if f not in idx[n]:
                     idx[n][f] = dict()
 
                 for op in oidx[n][of]:  # positions
@@ -407,12 +402,12 @@ def blastx(filepath, length, startcod, stopcod, fas2len,
 
     # TODO remove acc (only used for determining the plot path -> store plots
     # in blast dir? )
-    if acc == None:
+    if acc is None:
         acc = fastafile.split("/")[-1]
 
     # if the code is given the algorithm searches for nearby start and stop codons
     # thus, the sequence has to be read in this case
-    if code != None:
+    if code is not None:
         # read sequence
         sequence = sequences_fromfile(fastafile, circular=circular)[0]
 
@@ -426,7 +421,7 @@ def blastx(filepath, length, startcod, stopcod, fas2len,
         # determine if its in prot or nuc
         pth = f.split('/')[-2]
 
-        if ( pth == "nuc" and not cr ) or \
+        if (pth == "nuc" and not cr) or \
                 (pth == "prot" and not prot):
             continue
 
@@ -495,7 +490,7 @@ def blastx(filepath, length, startcod, stopcod, fas2len,
 
 
 def blastn(filepath, cutoff=0, minevalue=0, acc=None):
-    if acc == None:
+    if acc is None:
         acc = filepath.split("/")[-1]
 
     # Check if it is in %
@@ -504,7 +499,7 @@ def blastn(filepath, cutoff=0, minevalue=0, acc=None):
         if cutoff[0] == "%":
             percent = True
             cutoff = float(cutoff[1:]) / 100
-    except:
+    except Exception:
         # if not percent the Cutoff ist a Int
         cutoff = int(cutoff)
 
@@ -581,7 +576,7 @@ def blastn(filepath, cutoff=0, minevalue=0, acc=None):
                     hits[strand[name]] += 1
                     # poscount[rf] = poscount[rf].union(set(range(start,stop)))
                     for i in range(start, stop):
-                        if not i in posgenes[name][strand[name]]:
+                        if i not in posgenes[name][strand[name]]:
                             posgenes[name][strand[name]][i] = 1
                         else:
                             posgenes[name][strand[name]][i] += 1
@@ -612,7 +607,7 @@ def blastn(filepath, cutoff=0, minevalue=0, acc=None):
             posgenes[name] = [i for i in posgenes[name]]
             posgenes[name].sort()
 
-        except:
+        except Exception:
             logging.warning(
                 "blastfile error: could not open file %s\n" % _file)
 
@@ -773,11 +768,11 @@ def _clip_predictions(h1, h2, idx, values):
 #     else:
 #         hit2 = feature.blast_feature( hit2.name, hit2.type, hit2.strand, positions, mito = 1, rf = hit2.rf )
 
-    if hit1 == None:
+    if hit1 is None:
         pass
-    elif hit2 == None:
+    elif hit2 is None:
         hit1, hit2 = hit2, hit1
-    elif hit1 == None and hit2 == None:
+    elif hit1 is None and hit2 is None:
         logging.error("clip predictions yielded 2 None features")
         raise Exception("clip predictions yielded 2 None features")
     elif swap:
@@ -789,10 +784,10 @@ def _clip_predictions(h1, h2, idx, values):
 def _create_initial_predictions(idx, values, cutoff):
     """
     Determine features, i.e. consecutive stretches of positions (in the
-    same reading frame) which have blast hits. In this version a maximum 
-    (and threshold) is computed and the threshold is applied per stretch.   
+    same reading frame) which have blast hits. In this version a maximum
+    (and threshold) is computed and the threshold is applied per stretch.
 
-    This is done separately per gene and reading frame. 
+    This is done separately per gene and reading frame.
     For every hit the average (over the length of the feature)
     evalue and height (number of hits) is computed.
     Furthermore the average query start and stop position is stored.query,
@@ -846,24 +841,24 @@ def _create_initial_predictions(idx, values, cutoff):
 #                 logging.warn( "maxv %s %s" % ( str( maxp.get_score( ) ), str( maxv ) ) )
 #                 logging.warn( "maxi %s" % str( maxi ) )
 
-                l = maxi
-                r = maxi
-                while l > 0:
+                left = maxi
+                right = maxi
+                while left > 0:
                     #                     logging.warn( "check %d %f" % ( l - 1, cp[l - 1].get_score( ) ) )
-                    if cp[l - 1].get_score() >= maxv:
-                        l -= 1
+                    if cp[left - 1].get_score() >= maxv:
+                        left -= 1
                     else:
                         break
-                while r < (len(cp) - 1):
+                while right < (len(cp) - 1):
                     #                     logging.warn( "check %d %f" % ( r + 1, cp[r + 1].get_score( ) ) )
-                    if cp[r + 1].get_score() >= maxv:
-                        r += 1
+                    if cp[right + 1].get_score() >= maxv:
+                        right += 1
                     else:
                         break
 #                 logging.warn( "===> %d-%d" % ( l, r ) )
 #                 logging.warn( " ".join( [str( x.get_position() ) for x in cp[l:r + 1]] ) )
                 hits.append(feature.blast_feature(
-                    name, type_from_name(name), strand, cp[l:r + 1], mito=1, rf=rf))
+                    name, type_from_name(name), strand, cp[left:right + 1], mito=1, rf=rf))
     return hits
 
 
@@ -1149,7 +1144,7 @@ def _aggregate_iter(blasthits, values, featlen, gname=""):
         fac = feature.length(min(h.qstart, h.qstop), max(
             h.qstart, h.qstop), False, 0) / float(h.length(False, 0))
         for i in feature.crange(h.start, h.stop + 1, 1, False, 0):
-            if not i in idx[h.rf]:
+            if i not in idx[h.rf]:
                 idx[h.rf][i] = len(values)
                 values.append(position_values(i))
             p = idx[h.rf][i]
@@ -1228,12 +1223,12 @@ def _aggregate_sweep(blasthits, values, featlen, gname):
         #         logging.debug( "H %s" % str( b ) )
         try:
             events[b.start].append(b)
-        except:
+        except KeyError:
             events[b.start] = [b]
 
         try:
             events[b.stop + 1].append(b)
-        except:
+        except KeyError:
             events[b.stop + 1] = [b]
 #         if cnt > 1:
 #             break
@@ -1264,7 +1259,7 @@ def _aggregate_sweep(blasthits, values, featlen, gname):
         # add sum for everything from the last event to the current
         # if there is something to add (height > 0)
         # and update the aggregated relative query position by dq
-        if prevev != None:
+        if prevev is not None:
             for f in cv:
                 if cv[f].get_height() <= 0:
                     continue
@@ -1471,7 +1466,7 @@ def _blasthandle(blastfile, minevalue, values, featlen,
         #         for i in sorted( idx[rf].iterkeys() ):
         #             logging.debug( "%s %d %s " % ( gname, rf, values[idx[rf][i]] ) )
         # #             values[idx[rf][i]].finalize()
-        for p in idx[rf].values():
+        for p in list(idx[rf].values()):
             values[p].finalize()
         if len(idx[rf]) == 0:
             del idx[rf]
@@ -1511,7 +1506,6 @@ def _improve_start_stop(hit, seq, code,
     @param[in] circular genome circularity
     @return plot data
     """
-
     if len(hit) > 1:
         logging.debug("_improve_start_stop %s .. %s %s" %
                       (str(hit[0]), str(hit[-1]), str(circular)))
@@ -1568,7 +1562,7 @@ def _improve_start_stop(hit, seq, code,
         if plat[1] - 3 > hit[-1].start and plat[0] + 3 <= plat[1] - 3:
             plat[1] -= 3
             mod = True
-#     logging.debug( "\tplat %s %s with value %f " % ( plat[0], plat[1], mx ) )
+    # logging.debug("\tplat %s %s with value %f " % (plat[0], plat[1], mx))
 
 #     if plat[1] < plat[0] and not circular:
 #         logging.error( "_improve_start_stop: invalid plat %d %d" % ( plat[0], plat[1] ) )
@@ -1577,16 +1571,24 @@ def _improve_start_stop(hit, seq, code,
     # this determines the range to search for the start and stop
     i = plat[0]
     while (not circular and i >= 0) or (circular and (i <= plat[0] or (i > plat[0] and i > plat[1]))):
-        if _get_codon(i, hit[0].strand, seq).isstop(code):
-            #             logging.debug( "left stop %d due to stop %s" % ( i, str( _get_codon( i, hit[0].strand, seq ) ) ) )
+        cdn = _get_codon(i, hit[0].strand, seq)
+        if cdn.isstop(code):
             rng[0] = i
+            # logging.debug("left stop %d %d due to stop %s" % (i, rng[0], str(_get_codon(i, hit[0].strand, seq))))
             break
+        # elif str(cdn) == "NNN":
+        #     if i == plat[0]:
+        #         rng[0] = plat[0]
+        #     else:
+        #         rng[0] = (i + 3) % len(seq)
+        #     logging.debug("left stop %d %d due to ambig %s" % (i, rng[0], str(_get_codon(i, hit[0].strand, seq))))
+        #     break
         trnaovl = False
         for t in forbidden:
             cap = feature.cap(i, plat[0], t.start, t.stop, True, len(seq))
             if cap == t.length(True, len(seq)):
                 trnaovl = True
-#                 logging.debug( "left stop %d due to forbidden overlap with %s" % ( i, str( t ) ) )
+                # logging.debug("left stop %d due to forbidden overlap with %s" % (i, str(t)))
                 break
         if trnaovl:
             break
@@ -1598,15 +1600,23 @@ def _improve_start_stop(hit, seq, code,
 
     i = plat[1]
     while (not circular and i <= len(seq) - 3) or (circular and (i >= plat[1] or (i < plat[1] and i < plat[0]))):
-        if _get_codon(i, hit[-1].strand, seq).isstop(code):
-            #             logging.debug( "right stop %d due to stop %s" % ( i, str( _get_codon( i, hit[-1].strand, seq ) ) ) )
+        cdn = _get_codon(i, hit[-1].strand, seq)
+        if cdn.isstop(code):
+            # logging.debug("right stop %d due to stop %s" % (i, str(cdn)))
             rng[1] = i
             break
+        # elif str(cdn) == "NNN":
+        #     if i == plat[1]:
+        #         rng[1] = plat[1]
+        #     else:
+        #         rng[1] = (i - 3) % len(seq)
+        #     logging.debug("right stop %d %d due to ambig %s" % (i, rng[1], str(cdn)))
+        #     break
         trnaovl = False
         for t in forbidden:
             cap = feature.cap(plat[1], i, t.start, t.stop, True, len(seq))
             if cap == t.length(True, len(seq)):
-                #                 logging.debug( "right stop %d due to forbidden overlap with %s" % ( i, str( t ) ) )
+                # logging.debug("right stop %d due to forbidden overlap with %s" % (i, str(t)))
                 trnaovl = True
                 break
         if trnaovl:
@@ -1648,8 +1658,7 @@ def _improve_start_stop(hit, seq, code,
 #         if trnaovl:
 #             rng[1] = i
 #             break
-#     logging.debug( "\trng %s(%s) %s(%s)" % ( str( rng[0] ), str( _get_codon( rng[0], hit[0].strand, seq ) ), str( rng[1] ),
-# str( _get_codon( rng[1], hit[-1].strand, seq ) ) ) )
+    # logging.debug("\trng %s %s" % (str(rng[0]), str(rng[1])))
 
     # initialize
     # codp: codon probabilities
@@ -1669,6 +1678,8 @@ def _improve_start_stop(hit, seq, code,
     # that is positions are sorted outside-to-inside
     positions = [feature.crange(rng[0], plat[0] + 1, 3, True, len(seq)),
                  feature.crange(rng[1], plat[1] - 1, -3, True, len(seq))]
+    # logging.error(f"0: {rng[0]}, {plat[0] + 1} {positions[0]}")
+    # logging.error(f"0: {rng[1]}, {plat[1] - 1} {positions[1]}")
     # get normalized quality values, more precicely normalized quality+1
 
     # get codon probabilities and degeneration malus
@@ -1850,7 +1861,7 @@ def _improve_start_stop(hit, seq, code,
                 try:
                     val *= crit[c][i]
                     val *= crit[c][j]
-                except:
+                except KeyError:
                     val *= crit[c][(i, j)]
 
             ret.append("{gene} {strand} {start} {stop} {pva:e} {va:e} {ci} {qi} {di} {fi} {mi} {cj} {qj} {dj} {fj} {mj}\n".format(
@@ -1870,25 +1881,23 @@ def _improve_start_stop(hit, seq, code,
                 best = val
                 hit[0].start = nstart
                 hit[-1].stop = nstop
+                # logging.debug("\t\tUPDATING to %d %d" % (nstart, nstop))
 
     # if the hit got extended to regions where no support from quality
     # values is available then corresponding values (0) need to be inserted
     # at these positions
     logging.debug("\tbest %f" % (best))
     if len(hit) == 1:
+        logging.debug("\t==> %s" % (str(hit)))
         if hit[0].start != ostart or hit[0].stop != ostop:
             _update_hit(hit[0], idx, values, circular, len(seq))
     else:
+        logging.debug("\t==> %s .. %s" % (str(hit[0]), str(hit[-1])))
         if hit[0].start != ostart:
             _update_hit(hit[0], idx, values, circular, len(seq))
         if hit[-1].stop != ostop:
             _update_hit(hit[-1], idx, values, circular, len(seq))
 
-    if len(hit) > 1:
-        logging.debug("\t==> %s .. %s" % (str(hit[0]), str(hit[-1])))
-    else:
-        logging.debug("\t==> %s" % (str(hit)))
-
 #     for i in [0, -1]:
 #         for p in positions[i]:
 #             if crit["codp"][p] == 0:
@@ -1954,7 +1963,7 @@ def _improve_start_stop_old(hit, code, sequence, length, idx, values, ststrange=
     logging.debug("=> %s" % (str(hit)))
 
 #     # improve start / stop codons
-#     if code != None:
+#     if code is not None:
 #         for name in predictions.keys():
 #             if name in ["OH", "OL"]:
 #                 continue
@@ -2018,8 +2027,8 @@ def _create_protplotdata(fname, idx, values):
         # sort by position (and reverse score)
         tab.sort(key=lambda a: (a[0], -a[1]))
         # remove entries at the same position with smaller score
-        for i in reversed(range(1, len(tab))):
-            if(tab[i][0] == tab[i - 1][0] and tab[i][1] <= tab[i - 1][1]):
+        for i in reversed(list(range(1, len(tab)))):
+            if tab[i][0] == tab[i - 1][0] and tab[i][1] <= tab[i - 1][1]:
                 del tab[i]
 
         if len(tab) > 0:
@@ -2118,7 +2127,7 @@ def _nonoverlapping_greedy(hits, idx, values, finovl, clipfac, scoresel='e', pav
                 logging.debug("                 %s %s" %
                               (str(hits[i]), str(hits[j])))
 
-                if hits[i] == None:
+                if hits[i] is None:
                     del hits[i]
                 else:
                     i = i + 1
@@ -2139,7 +2148,7 @@ def _nonoverlapping_greedy_sorted(hits, finovl):
     as conflict occur more easily)
     @param hits: a list of initial predictions
     @param finovl: maximum overlap between predictions
-    @return: a non-overlapping subset of hits 
+    @return: a non-overlapping subset of hits
     """
 
     # remove hits that overlap by more than 20% (of the length of one of the
@@ -2203,14 +2212,13 @@ def _update_hit(hit, idx, values, circular=False, length=0):
 
     for p in feature.crange(hit.start, hit.stop + 1, 1, circular, length):
         if p in idx[hit.rf]:
-            if start == None or p < start.get_position():
+            if start is None or p < start.get_position():
                 start = values[idx[hit.rf][p]]
-            if stop == None or p > stop.get_position():
+            if stop is None or p > stop.get_position():
                 stop = values[idx[hit.rf][p]]
         else:
             idx[hit.rf][p] = len(values)
             values.append(position_values(p))
-
     conspos = []
     for p in feature.crange(hit.start, hit.stop + 1, 1, circular, length):
         #         if p in not idx[hit.rf]:
