@@ -1,22 +1,19 @@
 '''
 @author: M. Bernt
 
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
-
 does the protein prediction and writes fasta output
-(let ABC be the base name of the input file and XYZ the name of a predicted gene) 
+(let ABC be the base name of the input file and XYZ the name of a predicted gene)
 
 input/output files:
-- ABC/blast/prot/ABC.XYZ.blast (the original BLAST output) 
+- ABC/blast/prot/ABC.XYZ.blast (the original BLAST output)
   if not present these files are created, otherwise they are used
 - XYZ.aa.fas: aminoacid sequence of the (best) prediction
   sequences are appended
 - XYZ.nt.fas: nucleotide sequence of the (best) prediction
   sequences are appended
 - genes.tab: absence/presence tabular
-  data is appended 
-- ABC/ABC.bed bed output of the best predictions 
+  data is appended
+- ABC/ABC.bed bed output of the best predictions
 - ABC/blast/prot/plot/XYZ/[+-123]
   ABC/blast/prot/plot/XYZ_[+-123].ps
   of --plot then plots and original output per reading frame
@@ -24,30 +21,30 @@ input/output files:
 @author: maze
 '''
 
-from optparse import OptionParser, OptionGroup
-from os.path import isfile, isdir, splitext, exists, basename
+from optparse import OptionGroup, OptionParser
 from os import listdir, mkdir
+from os.path import basename, exists, isdir, isfile, splitext
+from random import choice, shuffle
 from sys import exit, stderr
-from random import shuffle, choice
 
 from Bio import Data
 
-from bedfile import bedwriter
-from blast import blastx
-from gb import gbfromfile
-import mito
-from update import singleblastx
-from sequence import sequence_info_fromfile, sequence
+from mitos import mito
+from mitos.bedfile import bedwriter
+from mitos.blast import blastx
+from mitos.gb import gbfromfile
+from mitos.sequence import sequence, sequence_info_fromfile
+from mitos.update import singleblastx
 
 usage = """%prog [options] fasta files/fasta directory"
-    predicts proteins with blastx, and writes the aminoacid sequences  
+    predicts proteins with blastx, and writes the aminoacid sequences
 
-genetic code: 
+genetic code:
 - if genbank file with same name is found the code specified there is assumed
 - otherwise the genetic code specified with --code is assumed
-circularity is assumed to circular per default: 
+circularity is assumed to circular per default:
 - if genbank file with same name is found the circularity is taken from there
-- otherwise default circularity is assumed (can be set to linear with --linear)      
+- otherwise default circularity is assumed (can be set to linear with --linear)
 """
 parser = OptionParser(usage)
 parser.add_option("--code", action="store", type="int", metavar="CODE",
@@ -123,18 +120,18 @@ for f in files:
     if exists(f + ".gb"):
         gb = gbfromfile(f + ".gb")
 
-    if options.code != None:
+    if options.code is not None:
         code = options.code
-    elif gb != None:
+    elif gb is not None:
         code = gb.transl_table
     else:
         stderr.write(
             "no genbank file and no code specified for %s -> skipping\n" % f)
         continue
 
-    if options.circular != None:
+    if options.circular is not None:
         circ = options.circular
-    elif gb != None:
+    elif gb is not None:
         circ = gb.circular
     else:
         stderr.write(
@@ -150,7 +147,7 @@ for f in files:
         continue
     seq = seq[0]
 
-    if gb != None:
+    if gb is not None:
         name = gb.name
         acc = gb.accession
     else:
@@ -165,10 +162,10 @@ for f in files:
     # check for too many N's in the sequence
     freq = seq.nucleotide_frequency(osb=False)
     freqsum = 0.0
-    for l in freq:
-        if l in Data.IUPACData.unambiguous_dna_letters:
+    for letter in freq:
+        if letter in Data.IUPACData.unambiguous_dna_letters:
             continue
-        freqsum += freq[l]
+        freqsum += freq[letter]
     if freqsum > 0.05:
         stderr.write("%s %f%% non standard bases -> abort\n" % (acc, freqsum))
         exit()
@@ -195,18 +192,18 @@ for f in files:
     protdict = dict()
     for p in range(len(protlist)):
         # stdout.write( "%s\n" % protlist[p] )
-        if protlist[p].copy == None:
+        if protlist[p].copy is None:
             copy = 0
         else:
             copy = protlist[p].copy
-        if protlist[p].part == None:
+        if protlist[p].part is None:
             part = 0
         else:
             part = protlist[p].part
 
-        if not protlist[p].name in protdict:
+        if protlist[p].name not in protdict:
             protdict[protlist[p].name] = dict()
-        if not copy in protdict[protlist[p].name]:
+        if copy not in protdict[protlist[p].name]:
             protdict[protlist[p].name][copy] = dict()
         protdict[protlist[p].name][copy][part] = p
 
@@ -233,14 +230,14 @@ for f in files:
         bestval = 0  # best score
         for copy in list(protdict[name].keys()):
             v = 0.0
-            l = 0
+            el = 0
             for part in list(protdict[name][copy].keys()):
-                l += protlist[protdict[name][copy]
+                el += protlist[protdict[name][copy]
                               [part]].length(circ, len(seq))
                 v += protlist[protdict[name][copy][part]].score
 
             if options.havg:
-                v /= l
+                v /= el
 
             if v >= bestval:
                 if v > bestval:
@@ -249,7 +246,7 @@ for f in files:
                 bestcopy.append(copy)
 
         for copy in list(protdict[name].keys()):
-            if not copy in bestcopy:
+            if copy not in bestcopy:
                 del protdict[name][copy]
 
     # write bed file
@@ -274,7 +271,7 @@ for f in files:
             ntseq += seq.subseq(q.start, q.stop, q.strand)
 
         # write nucleotid sequence
-        if not p.name in ntfiles:
+        if p.name not in ntfiles:
             ntfiles[p.name] = open("%s/%s.nt.fas" % (directory, p.name), "a")
         ntfiles[p.name].write(">%s %s %d %d %d (%d)\n" % (
             acc, p.name, p.start, p.stop, p.strand, len(protdict[name][copy])))
@@ -300,7 +297,7 @@ for f in files:
             stderr.write("%s\n" % (str(aaseq)))
 
         # write aminoacid sequence
-        if not p.name in aafiles:
+        if p.name not in aafiles:
             aafiles[p.name] = open("%s/%s.aa.fas" % (directory, p.name), "a")
         aafiles[p.name].write(">%s %s %d %d %d (%d)\n" % (
             acc, p.name, p.start, p.stop, p.strand, len(protdict[name][copy])))
