@@ -1,17 +1,18 @@
 '''
 @author: M. Bernt
-
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
 '''
 
 import copy
 import itertools
 import logging
 import math
-from sys import stderr, exit, stdout
+from sys import stderr, stdout
 
-from ..mito import revtrnamap, rrnamap, revprot
+from mitos.mito import (
+    revprot,
+    revtrnamap,
+    rrnamap,
+)
 
 # TODO documentation
 
@@ -61,7 +62,7 @@ def cap(start1, stop1, start2, stop2, circular, size):
         else:
             stderr.write(
                 "error: unhandled feature position case for overlap computation\n")
-            stderr.write("%(%d,%d) (%d,%d)\n" % (start1, stop1, start2, stop2))
+            stderr.write("%%(%d,%d) (%d,%d)\n" % (start1, stop1, start2, stop2))
             return 0, 0
     else:
         if not circular:
@@ -71,14 +72,11 @@ def cap(start1, stop1, start2, stop2, circular, size):
                 raise LinearSequenceIndexError(start2, stop2)
 
         if start1 > stop1 and start2 <= stop2:
-            return cap( start1, size - 1, start2, stop2, circular, size ) + \
-                cap(0, stop1, start2, stop2, circular, size)
+            return cap(start1, size - 1, start2, stop2, circular, size) + cap(0, stop1, start2, stop2, circular, size)
         elif start1 <= stop1 and start2 > stop2:
-            return cap( start1, stop1, start2, size - 1, circular, size ) + \
-                cap(start1, stop1, 0, stop2, circular, size)
+            return cap(start1, stop1, start2, size - 1, circular, size) + cap(start1, stop1, 0, stop2, circular, size)
         else:
-            return cap( start1, size - 1, start2, size - 1, circular, size ) + \
-                cap(0, stop1, 0, stop2, circular, size)
+            return cap(start1, size - 1, start2, size - 1, circular, size) + cap(0, stop1, 0, stop2, circular, size)
 
 
 def cup(start1, stop1, start2, stop2, circular, size):
@@ -100,7 +98,7 @@ def cup(start1, stop1, start2, stop2, circular, size):
         else:
             stderr.write(
                 "error: unhandled feature position case for overlap computation\n")
-            stderr.write("%(%d,%d) (%d,%d)\n" % (start1, stop1, start2, stop2))
+            stderr.write("%%(%d,%d) (%d,%d)\n" % (start1, stop1, start2, stop2))
             return 0, 0
     else:
         if not circular:
@@ -110,14 +108,11 @@ def cup(start1, stop1, start2, stop2, circular, size):
                 raise LinearSequenceIndexError(start2, stop2)
 
         if start1 > stop1 and start2 <= stop2:
-            return cup( start1, size - 1, start2, stop2, circular, size ) + \
-                cup(0, stop1, start2, stop2, circular, size)
+            return cup(start1, size - 1, start2, stop2, circular, size) + cup(0, stop1, start2, stop2, circular, size)
         elif start1 <= stop1 and start2 > stop2:
-            return cup( start1, stop1, start2, size - 1, circular, size ) + \
-                cup(start1, stop1, 0, stop2, circular, size)
+            return cup(start1, stop1, start2, size - 1, circular, size) + cup(start1, stop1, 0, stop2, circular, size)
         else:
-            return cup( start1, size - 1, start2, size - 1, circular, size ) + \
-                cup(0, stop1, 0, stop2, circular, size)
+            return cup(start1, size - 1, start2, size - 1, circular, size) + cup(0, stop1, 0, stop2, circular, size)
 
 
 def capcup(start1, stop1, start2, stop2, circular, size):
@@ -148,7 +143,7 @@ def capcup(start1, stop1, start2, stop2, circular, size):
         else:
             stderr.write(
                 "error: unhandled feature position case for overlap computation\n")
-            stderr.write("%(%d,%d) (%d,%d)\n" % (start1, stop1, start2, stop2))
+            stderr.write("%%(%d,%d) (%d,%d)\n" % (start1, stop1, start2, stop2))
             return 0, 0
     else:
         if not circular:
@@ -178,8 +173,8 @@ def crange(start, stop, step, circular, length):
     @param start start of the xrange
     @param stop stop of the xrange (not included)
     @param step step size (int != 0)
-    @param circular circularity 
-    @param length length 
+    @param circular circularity
+    @param length length
 
     @return in iterable
     """
@@ -190,7 +185,7 @@ def crange(start, stop, step, circular, length):
                 return list(range(start, stop, step))
             else:
                 restart = (step - 1) - ((length - 1 - start) % step)
-                return list(itertools.chain(range(start, length, step), range(restart, stop, step)))
+                return list(itertools.chain(list(range(start, length, step)), list(range(restart, stop, step))))
         else:
             if start <= stop:
                 return list(range(start, stop, step))
@@ -202,7 +197,7 @@ def crange(start, stop, step, circular, length):
                 return list(range(start, stop, step))
             else:
                 restart = (length + step) + (start % abs(step))
-                return list(itertools.chain(range(start, -1, step), range(restart, stop, step)))
+                return list(itertools.chain(list(range(start, -1, step)), list(range(restart, stop, step))))
         else:
             if start >= stop:
                 return list(range(start, stop, step))
@@ -214,7 +209,7 @@ def crange(start, stop, step, circular, length):
 
 def length(start, stop, circular, size):
     """
-    get the length of a feature with 1st position at start and last position 
+    get the length of a feature with 1st position at start and last position
     at stop, circularity and size of the chromosome are regarded
 
     @param start 1st position
@@ -239,16 +234,16 @@ def length(start, stop, circular, size):
 def genorderwriter(featurelist, acc, outfile, mode="w", start=None, signed=True):
     featurelist.sort(key=lambda x: x.start)
 
-    if start != None:
+    if start is not None:
         i = 0
-        while(i < len(featurelist) and featurelist[i].outputname(False) != start):
+        while i < len(featurelist) and featurelist[i].outputname(False) != start:
             i += 1
 
         featurelist = featurelist[i:] + featurelist[:i]
 
     out = ">%s\n" % (acc)
     for feat in featurelist:
-        if signed == True and feat.strand < 0:
+        if signed is True and feat.strand < 0:
             out += "-%s " % (feat.outputname(False))
         else:
             out += "%s " % (feat.outputname(False))
@@ -257,7 +252,7 @@ def genorderwriter(featurelist, acc, outfile, mode="w", start=None, signed=True)
     if isinstance(outfile, str):
         with open(outfile, mode) as f:
             f.write(out)
-    elif outfile == None:
+    elif outfile is None:
         stdout.write(out)
     else:
         outfile.write(out)
@@ -301,22 +296,22 @@ def remove_circular_duplicates2(flist, length, extlength):
 
 def remove_circular_duplicates(flist, length):
     """
-    remove redundant hits from a list of features that have 
+    remove redundant hits from a list of features that have
     been determined for a duplicated genome (in order to treat circularity)
 
-    - it determines the features spanning the end of the linearized genome,  
+    - it determines the features spanning the end of the linearized genome,
       i.e. spanning the position length
-    - if no such feature is present 
-      -> the features in [length:]are removed    
+    - if no such feature is present
+      -> the features in [length:]are removed
     - else:
-      the feature C of those spanning the end with maximum stop position is determined 
+      the feature C of those spanning the end with maximum stop position is determined
       -> features starting after C (i.e. C.stop % lenght)
-         and stopping before C+ the lenghth x of the longest fecture in flist 
+         and stopping before C+ the lenghth x of the longest fecture in flist
          (i.e. C.start + x) are accepted
 
-    assumptions: 
+    assumptions:
     - 0 based positions, end position excluded
-    - non-overlapping features, i.e. only one spans the end of the genome 
+    - non-overlapping features, i.e. only one spans the end of the genome
 
     @param[in] flist list of features
     @param[in] length length of the genome
@@ -378,11 +373,11 @@ class feature:
         @param start start position (counting starts at 0, start position belongs to the gene)
         @param stop stop position (counting starts at 0, stop position belongs to the gene)
         @param strand strand (+1/-1)
-        @param method method used for predicting the gene 
-        @param translation 
+        @param method method used for predicting the gene
+        @param translation
         @param score some raw score, e.g.  bitscore
-        @param rf 
-        @param anticodon the anticodon: of type trna.codon 
+        @param rf
+        @param anticodon the anticodon: of type trna.codon
         @param copy copy number of the feature
         @param part part number of the feature
         @param mito 1 if to be annotated in the 1st round of mitos and 2 otherwise
@@ -398,7 +393,6 @@ class feature:
         self.stop = stop
         self.strand = strand
         self.method = method
-
         self.translation = translation
         self.score = score
         self.rf = rf
@@ -416,7 +410,7 @@ class feature:
         @return False if name, start, stop, strand, or translation are different True otherwise
         """
 
-        if other == None:
+        if other is None:
             return False
 
         if not self.equal_name_type(other):
@@ -443,13 +437,13 @@ class feature:
 
     def __repr__(self):
         """
-        get a string 
+        get a string
         """
         return "%s(%s, %d, %d..%d)" % (self.type, self.getname(), self.strand, self.start, self.stop)
 
     def __str__(self):
         """
-        get a string 
+        get a string
         """
         return '{0:4}({1:>4},{2:1},{3:5d},{4:5d},{5:5}, {6})'.format(self.type, self.getname(), self.plusminus(), self.start, self.stop, self.method, self.score)
 
@@ -468,7 +462,7 @@ class feature:
         """
         compute the size (i.e. nr of positions) of the intersection and union of two features
         @param self the feature
-        @param other another feature  
+        @param other another feature
         @param circularity True iff the chromosome housing the feature is circular
         @param size size of the chromosome housing the feature
 
@@ -514,10 +508,10 @@ class feature:
         @return False if name or type differ, True otherwise
         """
         if self.name != other.name:
-            if not((self.name == "trnL" and (other.name == "trnL1" or other.name == "trnL2")) or
-                    (other.name == "trnL" and (self.name == "trnL1" or self.name == "trnL2")) or
-                    (self.name == "trnS" and (other.name == "trnS1" or other.name == "trnS2")) or
-                   (other.name == "trnS" and (self.name == "trnS1" or self.name == "trnS2"))):
+            if not ((self.name == "trnL" and (other.name == "trnL1" or other.name == "trnL2"))
+                    or (other.name == "trnL" and (self.name == "trnL1" or self.name == "trnL2"))
+                    or (self.name == "trnS" and (other.name == "trnS1" or other.name == "trnS2"))
+                    or (other.name == "trnS" and (self.name == "trnS1" or self.name == "trnS2"))):
                 return False
             # return False
         if self.type != other.type:
@@ -528,14 +522,14 @@ class feature:
     def is_allowed(self, aname=None, fname=None, atype=None,
                    ftype=None, astrand=None, amethod=None, fmethod=None):
         """
-        checks if the feature is of a certain type or name 
-        @param atype list of allowed types or a string of a type  
-        @param ftype forbidden types 
-        @param aname list of allowed names or a string of a name  
-        @param fname forbidden names 
-        @param astrand allowed strand 
-        @param fmethod forbidden method 
-        @param amethod allowed method 
+        checks if the feature is of a certain type or name
+        @param atype list of allowed types or a string of a type
+        @param ftype forbidden types
+        @param aname list of allowed names or a string of a name
+        @param fname forbidden names
+        @param astrand allowed strand
+        @param fmethod forbidden method
+        @param amethod allowed method
         @return true if feature in atype and feature not in ftype and name in aname and name not in fname
         """
 
@@ -544,9 +538,9 @@ class feature:
         if isinstance(ftype, str):
             ftype = [ftype]
 
-        if atype != None and self.type not in atype:
+        if atype is not None and self.type not in atype:
             return False
-        elif ftype != None and self.type in ftype:
+        elif ftype is not None and self.type in ftype:
             return False
 
         if isinstance(aname, str):
@@ -554,24 +548,24 @@ class feature:
         if isinstance(fname, str):
             fname = [fname]
 
-        if aname != None and "S" in aname:
+        if aname is not None and "S" in aname:
             aname.append("S1")
             aname.append("S2")
-        if fname != None and "S" in fname:
+        if fname is not None and "S" in fname:
             fname.append("S1")
             fname.append("S2")
-        if aname != None and "L" in aname:
+        if aname is not None and "L" in aname:
             aname.append("L1")
             aname.append("L2")
-        if fname != None and "L" in fname:
+        if fname is not None and "L" in fname:
             fname.append("L1")
             fname.append("L2")
 
-        if aname != None and self.name not in aname:
+        if aname is not None and self.name not in aname:
             return False
-        elif fname != None and self.name in fname:
+        elif fname is not None and self.name in fname:
             return False
-        elif astrand != None and self.strand != astrand:
+        elif astrand is not None and self.strand != astrand:
             return False
 
         if isinstance(amethod, str):
@@ -581,18 +575,18 @@ class feature:
 
         # need to get the local and global difference
         if self.method == "mitfi" and "local" in self.__dict__:
-            if self.local and amethod != None and "lmitfi" in amethod:
+            if self.local and amethod is not None and "lmitfi" in amethod:
                 return True
-            elif not self.local and amethod != None and "gmitfi" in amethod:
+            elif not self.local and amethod is not None and "gmitfi" in amethod:
                 return True
-            elif self.local and fmethod != None and "lmitfi" in fmethod:
+            elif self.local and fmethod is not None and "lmitfi" in fmethod:
                 return False
-            elif not self.local and fmethod != None and "fmitfi" in fmethod:
+            elif not self.local and fmethod is not None and "fmitfi" in fmethod:
                 return False
 
-        if amethod != None and self.method not in amethod:
+        if amethod is not None and self.method not in amethod:
             return False
-        elif fmethod != None and self.method in fmethod:
+        elif fmethod is not None and self.method in fmethod:
             return False
 
         return True
@@ -601,18 +595,18 @@ class feature:
         """
         this functions merges the info of two features and returns a new feature
         the new feature will be of the same type as the calling feature
-        the features need to have equal 
+        the features need to have equal
         - type, strand, start, stop, and method
-        - and name (up to L1/L2/L and S1/S2/S) 
+        - and name (up to L1/L2/L and S1/S2/S)
           L/S is overwitten if the other feature is L/S1/2
         - minimum of copy and part is chosen
         - all other properties need to be equal or one equal to None
-          then the non None property is taken 
+          then the non None property is taken
 
         raises FeatureUnAddable in case of error
 
         @param other the second feature
-        @return a new feature  
+        @return a new feature
         """
 
 #        print "merge", str( self ), str( other )
@@ -620,11 +614,11 @@ class feature:
         f = copy.deepcopy(self)
 
         # update of name is special
-        if  self.name == None or other.name.startswith( self.name ) or \
+        if self.name is None or other.name.startswith(self.name) or\
                 f.name.startswith("orf") and not other.name.startswith("orf"):
             f.name = other.name
             f.type = other.type
-        elif other.name == None or self.name.startswith( other.name ) or \
+        elif other.name is None or self.name.startswith(other.name) or \
                 not f.name.startswith("orf") and other.name.startswith("orf"):
             other.name = f.name
             other.type = f.type
@@ -639,12 +633,12 @@ class feature:
                 raise FeatureUnAddable(self, other)
 
         for m in f.__dict__:
-            if not m in other.__dict__:
+            if m not in other.__dict__:
                 continue
 
-            if f.__dict__[m] == None and other.__dict__[m] != None:
+            if f.__dict__[m] is None and other.__dict__[m] is not None:
                 f.__dict__[m] = other.__dict__[m]
-            elif f.__dict__[m] != None and other.__dict__[m] == None:
+            elif f.__dict__[m] is not None and other.__dict__[m] is None:
                 pass
             else:
                 if f.__dict__[m] == other.__dict__[m]:
@@ -684,9 +678,9 @@ class feature:
 #         prop = {}
 #
 #         # update of name is special
-#         if other.name.startswith( self.name ) or self.name == None:
+#         if other.name.startswith( self.name ) or self.name is None:
 #             prop["name"] = other.name
-#         elif self.name.startswith( other.name ) or other.name == None:
+#         elif self.name.startswith( other.name ) or other.name is None:
 #             prop["name"] = self.name
 #         else:
 #             raise FeatureUnAddable( self, other )
@@ -700,9 +694,9 @@ class feature:
 #
 #         # properties that should be updated
 #         for m in ["translation", "anticodon", "score", "rf", "copy", "part", "mito"]:
-#             if self.__dict__[m] == None and other.__dict__[m] != None:
+#             if self.__dict__[m] is None and other.__dict__[m] is not None:
 #                 prop[m] = other.__dict__[m]
-#             elif self.__dict__[m] != None and other.__dict__[m] == None:
+#             elif self.__dict__[m] is not None and other.__dict__[m] is None:
 #                 prop[m] = self.__dict__[m]
 #             else:  # both eq None or both are not eq None
 #                 if self.__dict__[m] == other.__dict__[m]:
@@ -738,8 +732,8 @@ class feature:
 
         @param self the feature
         @param other another feature
-        @param size of the chromosom housing the feature 
-        @return overlap percentage (i.e. 100*cap/cup) 
+        @param size of the chromosom housing the feature
+        @return overlap percentage (i.e. 100*cap/cup)
         """
 
         cap, cup = self.capcup(other, circular, size)
@@ -748,9 +742,9 @@ class feature:
 
     def getname(self):
         """
-        get a printable represenation of the gene name including the copy and 
+        get a printable represenation of the gene name including the copy and
         part information
-        @return X_Y_Z where X is the gene name, Y the copy number, and the part number (as character)  
+        @return X_Y_Z where X is the gene name, Y the copy number, and the part number (as character)
         """
 
         return self.outputname()
@@ -759,7 +753,7 @@ class feature:
         """
         this function returns the string to be written in a bed file
         """
-        if self.score != None:
+        if self.score is not None:
             s = str(self.score)
         else:
             s = "."
@@ -794,9 +788,8 @@ origin_of_replication
         gff = []
 
         trnstype = None
-        if self.part == 0 or self.part == None:
-            parts = [x for x in features if x.name ==
-                     self.name and x.copy == self.copy]
+        if self.part == 0 or self.part is None:
+            parts = [x for x in features if x.name == self.name and x.copy == self.copy]
             genestart = parts[0].start
             genestop = parts[-1].stop
             if self.type == "gene":
@@ -821,20 +814,20 @@ origin_of_replication
                 seqid=acc, source=self.method, type=genetype,
                 start=genestart + 1, end=genestop + 1, score=".", strand=self.plusminus(),
                 phase=".", name=self.outputname(anticodon=False, part=False)))
-            if trnstype != None:
+            if trnstype is not None:
                 gff.append("{seqid}\t{source}\t{type}\t{start}\t{end}\t{score}\t{strand}\t{phase}\tID=transcript_{name};Parent=gene_{name};gene_id={name}".format(
                     seqid=acc, source=self.method, type=trnstype,
                     start=genestart + 1, end=genestop + 1, score=".", strand=self.plusminus(),
                     phase=".", name=self.outputname(anticodon=False, part=False)))
 
-            if trnstype == None:
+            if trnstype is None:
                 return "\n".join(gff)
 
-        if self.score != None:
+        if self.score is not None:
             s = str(self.score)
         else:
             s = "."
-        if self.rf == None:
+        if self.rf is None:
             rf = "."
         else:
             rf = str(self.rf)
@@ -924,7 +917,7 @@ origin_of_replication
         """
         this function returns the string to be written in a mito file
         """
-        if self.score != None:
+        if self.score is not None:
             s = str(self.score)
         else:
             s = "."
@@ -934,28 +927,28 @@ origin_of_replication
         else:
             bs = "."
 
-        if self.anticodon != None:
+        if self.anticodon is not None:
             acodon = self.anticodon.get_anticodon()
         else:
             acodon = "-"
 
         try:
             acpos = str(self.anticodonpos)
-        except:
+        except Exception:
             acpos = "-"
 
-        if self.part != None:
+        if self.part is not None:
             part = str(self.part)
         else:
             part = "."
-        if self.copy != None:
+        if self.copy is not None:
             copy = str(self.copy)
         else:
             copy = "."
 
         try:
             struct = self.structure
-        except:
+        except Exception:
             struct = "."
 
         return "{acc}\t{tpe}\t{name}\t{meth}\t{start}\t{stop}\t{strand}\t{score}\t{bitscore}\t{anticodon}\t{anticodonpos}\t{part}\t{copy}\t{struct}".format(
@@ -968,7 +961,7 @@ origin_of_replication
         """
         generate the name output name NAME(AC)_COPY-PART
         @param anticodon include anticodon
-        @param copy include copy 
+        @param copy include copy
         @param part include part
         """
 #        if self.name.startswith( "ND" ):
@@ -990,12 +983,12 @@ origin_of_replication
 
         name += self.name
 
-        if copy and self.copy != None:
+        if copy and self.copy is not None:
             name += "_" + str(self.copy)
-        if part and self.part != None:
+        if part and self.part is not None:
             name += "-" + chr(97 + self.part)
         if anticodon and self.type == "tRNA":
-            if self.anticodon != None:
+            if self.anticodon is not None:
                 name += "(%s)" % self.anticodon.get_anticodon().lower()
             else:
                 name += "(---)"
@@ -1004,7 +997,7 @@ origin_of_replication
 
     def plusminus(self):
         """
-        @return '+' if on positive strand, '-' else 
+        @return '+' if on positive strand, '-' else
         """
         if self.strand > 0:
             return '+'
@@ -1014,34 +1007,34 @@ origin_of_replication
 
 class blast_feature(feature):
     """
-    a feature predicted with blast; 
-    derived from feature with the additional properties: 
+    a feature predicted with blast;
+    derived from feature with the additional properties:
     - qstart: avg. relative start position in the query
-    - qstop : avg. relative stop position in the query 
+    - qstop : avg. relative stop position in the query
     """
 
     def __init__(self, name, tpe, strand, positions, mito, rf, scoresel='e', havg=False, pavg=False):
         """
-        a feature determined from a list of consecutive positions with 
-        quality > 0, stores 
-        - _positions the positions 
-        - _evalue the evalue     determined as sum or average over all positions  
+        a feature determined from a list of consecutive positions with
+        quality > 0, stores
+        - _positions the positions
+        - _evalue the evalue     determined as sum or average over all positions
         - _bitscore bitscore     --------------------"--------------------------
         - _height numer of hits  --------------------"--------------------------
 
         @param name the name of the feature
         @param tpe the type of the feature
         @param strand strandedness (+1/-1)
-        @param positions: a list of positions, the first and the last in the list 
-            must be really the first and last position 
+        @param positions: a list of positions, the first and the last in the list
+            must be really the first and last position
         @param ascore: specify which value at the position should be used for
             the calculation of the score, 'h': height, 'e': (exponent of) evalue,
             'b': bitscore
-        @param havg: if False then get the sum of the values at the positions, 
+        @param havg: if False then get the sum of the values at the positions,
             if True then get the average of the summed values (i.e. divided by length)
         @param pavg: False: Sum of the values at a position
-            True: the average values at each position are summed  
-            (does not apply for height) 
+            True: the average values at each position are summed
+            (does not apply for height)
         @param mito
         @param rf
         """
@@ -1093,7 +1086,7 @@ class blast_feature(feature):
             raise Exception(
                 "init_score got invalid scoresel: %s" % self._scoresel)
 
-        if self._havg == False:
+        if self._havg is False:
             s *= ln
 
         s = round(s, 1)
@@ -1104,18 +1097,18 @@ class blast_feature(feature):
         update the feature with a new set of positions
         see init for options
 
-        the current value is kept for name, tpe, strand, mito, rf if parameter is None  
+        the current value is kept for name, tpe, strand, mito, rf if parameter is None
         """
 
         s = self.init_score(positions)
 
-        if rf == None:
+        if rf is None:
             rf = self.rf
-        if name == None:
+        if name is None:
             name = self.name
-        if tpe == None:
+        if tpe is None:
             tpe = self.type
-        if strand == None:
+        if strand is None:
             strand = self.strand
 
         feature.__init__(self, name, tpe,
@@ -1125,10 +1118,10 @@ class blast_feature(feature):
         self.qstart = positions[0].get_query()
         self.qstop = positions[-1].get_query()
 
-        if(self.qstart > self.qstop):
+        if self.qstart > self.qstop:
             self.qstart, self.qstop = self.qstop, self.qstart
 
-        if mito != None:
+        if mito is not None:
             self.mito = mito
 
     def __str__(self):
@@ -1142,8 +1135,8 @@ class blasthit_feature(feature):
     a feature for blast data; derived from feature with the additional properties:
     - query name
     - evalue:
-    - bitscore 
-    - qstart: 
+    - bitscore
+    - qstart:
     - qstop :
     """
 
@@ -1161,18 +1154,18 @@ class blasthit_feature(feature):
 
     def __str__(self):
         """
-        get a string 
+        get a string
         """
         return '{0:4}({1:>4},{2:1},{3:5d},{4:5d},{5:5}, {6}, {7})'.format(self.type, self.getname(), self.plusminus(), self.start + 1, self.stop + 1, self.method, self.score, self.evalue)
 
 
 class trnafeature(feature):
     """
-    a feature predicted with trna; derived from feature with the additional properties: 
+    a feature predicted with trna; derived from feature with the additional properties:
     @param score some raw score, e.g.  bitscore
-    - structure: 
-    - anticodonpos: 
-    - anticdon : 
+    - structure:
+    - anticodonpos:
+    - anticdon :
     - sequence:
     """
 
@@ -1189,7 +1182,7 @@ class trnafeature(feature):
 
     def __str__(self):
 
-        if self.anticodon != None:
+        if self.anticodon is not None:
             ac = " " + self.anticodon.get_anticodon()
         else:
             ac = ""
@@ -1202,14 +1195,14 @@ class trnafeature(feature):
 
 class mitfifeature(trnafeature):
     """
-    a trnafeature predicted with mitfi; derived from trnafeature with the additional properties: 
-    - qstart: 
+    a trnafeature predicted with mitfi; derived from trnafeature with the additional properties:
+    - qstart:
     - qstop:
-    - evalue 
-    - pvalue: 
+    - evalue
+    - pvalue:
     - model:
     - local: It is 0 if it is a global hit and it is 1 if it is a local hit
-    - mito: If we belive it is 2 if it is a copy it is 1 and if it is crap it is 0 
+    - mito: If we belive it is 2 if it is a copy it is 1 and if it is crap it is 0
     """
 
     def __init__(self, name, tpe, start, stop, strand, score, sequence, struct, anticodonpos,
