@@ -1,16 +1,13 @@
 """
 @author: M. Bernt
 
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
-
 Module that provides the diferent methods to merge featurelist.
 """
 
 import logging
 
-from ..mitfi import cmrealign
-from .. import feature
+from mitos import feature
+from mitos.mitfi import cmrealign
 
 
 def featureappend(appendList, featurelist, nfeaturelist, circular, length, overlap, rnd=False):
@@ -18,20 +15,20 @@ def featureappend(appendList, featurelist, nfeaturelist, circular, length, overl
     append a given list of features to an existing list of features such that
     no conflict emerges
 
-    conflict: overlap is larger than the maximum, i.e. >overlap or >len(tRNA)-1 
+    conflict: overlap is larger than the maximum, i.e. >overlap or >len(tRNA)-1
     for tRNA rRNA overlaps
 
-    if the rnd flag is set to True: 
+    if the rnd flag is set to True:
     if tRNA-rRNA overlap with tRNA e-value > 10^-3 and tRNA included in rRNA
-    the tRNA is removed 
+    the tRNA is removed
 
     @param[in,out] appendList the list of new features to be checked for insertion
     @param[in,out] featurelist the list where the new features should be appended
     @param[in,out] nfeaturelist the list where the non features should be appended
     @param[in] circular the circularity of the genome
-    @param[in] length the length of the genome 
+    @param[in] length the length of the genome
     @param[in] overlap maximum allowed overlap of two features
-    @param[in] rnd remove "low quality" tRNAs (from the feature list) that overlaps an rRNA (in appendList/featurelist) 
+    @param[in] rnd remove "low quality" tRNAs (from the feature list) that overlaps an rRNA (in appendList/featurelist)
     """
 
     # for tRNA check
@@ -62,7 +59,7 @@ def featureappend(appendList, featurelist, nfeaturelist, circular, length, overl
             if cap == slen or cap == flen:
                 # Intron encoded proteins can be included (usual restrictions
                 # apply if they overlap)
-                if ( ffeat.type == "Intron" and sfeat.name in [ "lagli", "giy"] and cap == slen ) or \
+                if (ffeat.type == "Intron" and sfeat.name in ["lagli", "giy"] and cap == slen) or \
                         (sfeat.type == "Intron" and ffeat.name in ["lagli", "giy"] and cap == flen):
                     continue
                 else:
@@ -71,15 +68,15 @@ def featureappend(appendList, featurelist, nfeaturelist, circular, length, overl
                     break
 
             # for tRNA - rRNA: check if the overlap is len(tRNA) -1
-            if ( sfeat.type == "tRNA" and ffeat.type == "rRNA" ) or \
+            if (sfeat.type == "tRNA" and ffeat.type == "rRNA") or \
                     (ffeat.type == "tRNA" and sfeat.type == "rRNA"):
 
                 if sfeat.type == "tRNA":
                     tr = sfeat
-                    #rr = ffeat
+                    # rr = ffeat
                 else:
                     tr = ffeat
-                    #rr = sfeat
+                    # rr = sfeat
 
                 maxoverlap = max(overlap, tr.length(circular, length) - 1)
                 # delete only in the first rnd
@@ -124,39 +121,39 @@ def featureappend(appendList, featurelist, nfeaturelist, circular, length, overl
 def appendlocalfeature(lokalHits, lname, rrnafeat, featurelist, seqlen,
                        allowoverlap=35, circular=True, debug=False):
     """
-    tries to fit in possible local hits. 
+    tries to fit in possible local hits.
 
-    A) a gap is searched, i.e. a region between two genes 
+    A) a gap is searched, i.e. a region between two genes
     1 if there is a global hit (which did not fit in) then a gap is searched
-      only in the region covered by the best global hit. except if there 
+      only in the region covered by the best global hit. except if there
       is no gap in this region, then the mode 2 is employed
       larger gaps are prefered.
     2 if there is no global hit the complete genome is considered.
 
 
-    In both modes the the gap that can take the best hit is searched. 
+    In both modes the the gap that can take the best hit is searched.
     That is the first gap that can take an (as goods as possible) feature.
-    The best features are tested first starting with the largest gaps.  
+    The best features are tested first starting with the largest gaps.
 
-    B) When the gap was found all local hits are removed that do not fit 
-    in the gap. Thus, also more than the best local hit can be chosen. 
+    B) When the gap was found all local hits are removed that do not fit
+    in the gap. Thus, also more than the best local hit can be chosen.
 
-    C) Finally the chosen local hits are checked if they overlap each other. 
+    C) Finally the chosen local hits are checked if they overlap each other.
     Good ones are preferred.
 
     @param[in] lokalHits the local hits for the rRNA with name lname
         - included features that overlap features in featurelist are removed
-        - but the remaining list is not the same as the features that are 
-          appended to featurelist! 
+        - but the remaining list is not the same as the features that are
+          appended to featurelist!
     @param[] lname the name of the rRNA
-    @param[] rrnafeat the global hits (to check if there is any. even 
+    @param[] rrnafeat the global hits (to check if there is any. even
              if it is not included in the featurelist [due to overlap])
     @param[in,out] featurelist the current list of features predicted by MITOS
     @param[in] seqlen length of the sequence
         - features from lokalHits are included if not in conflict
-    @param[] allowoverlap max allowed overlap with features in featurelist 
-             (for tRNAs len-1 is allowed)  
-    @param[in] circular circularity of the genome 
+    @param[] allowoverlap max allowed overlap with features in featurelist
+             (for tRNAs len-1 is allowed)
+    @param[in] circular circularity of the genome
     @param[in] length length of the genome
     """
 
@@ -185,15 +182,15 @@ def appendlocalfeature(lokalHits, lname, rrnafeat, featurelist, seqlen,
     # note the iteration is done circular manner regardless if the genome is
     # this is fixed below
     for j in range(len(featurelist)):
-        l = featurelist[j].stop
-        le = l - min(allowoverlap, featurelist[j].length(circular, seqlen) - 1)
+        el = featurelist[j].stop
+        le = el - min(allowoverlap, featurelist[j].length(circular, seqlen) - 1)
 
         r = featurelist[(j + 1) % len(featurelist)].start - 1
         re = r + \
             min(allowoverlap, featurelist[
                 (j + 1) % len(featurelist)].length(circular, seqlen) - 1)
 
-        gaps.append((l, r))
+        gaps.append((el, r))
         egaps.append((le, re))
 
     if not circular:
@@ -360,17 +357,17 @@ def appendlocalfeature(lokalHits, lname, rrnafeat, featurelist, seqlen,
 
 def checklocalfeature(localcheck, featurelist, sequence, refdir, circular, length, ):
     """
-    - remove single local feature <= 55 nt 
+    - remove single local feature <= 55 nt
 
-    - check and combine consecutive features that have been determined with 
-      local search if they can be merged:  
+    - check and combine consecutive features that have been determined with
+      local search if they can be merged:
       * same name, same strand
       * difference of the distance in sequence and query by factor < 1.5
 
-    @param localcheck the list of names of the rRNA(s) to check 
+    @param localcheck the list of names of the rRNA(s) to check
     @param featurelist the list of features
     @param sequence the sequence of the genome
-    @param refdir 
+    @param refdir
     @param circular is the sequence circular
     @param length sequence length
     """
@@ -403,7 +400,7 @@ def checklocalfeature(localcheck, featurelist, sequence, refdir, circular, lengt
 
         # features to merge must have the same name and in localcheck (i.e.
         # there must be local features of this type)
-        if featurelist[ i ].name not in localcheck or \
+        if featurelist[i].name not in localcheck or \
                 featurelist[i].name != featurelist[ii].name:
             i += 1
             continue
@@ -424,13 +421,12 @@ def checklocalfeature(localcheck, featurelist, sequence, refdir, circular, lengt
 
         # distance of the 2 features in the query positions, calculated as
         # distance of the mid points of the query ranges
-        querydist = ( featurelist[ii].qstop - featurelist[ii].qstart ) / 2.0 + featurelist[ii].qstart - \
-            ((featurelist[i].qstop - featurelist[i].qstart) /
-             2.0 + featurelist[i].qstart)
+        querydist = (featurelist[ii].qstop - featurelist[ii].qstart) / 2.0 + featurelist[ii].qstart - \
+            ((featurelist[i].qstop - featurelist[i].qstart) / 2.0 + featurelist[i].qstart)
 
         # features to merge must be in the same direction wrt query and
         # reference
-        if querydist > 0 and featurelist[ i ].strand < 0 or \
+        if querydist > 0 and featurelist[i].strand < 0 or \
                 querydist <= 0 and featurelist[i].strand > 0:
             logging.debug("checklocalfeature: wrong direction %s" % (info))
             i += 1
@@ -494,11 +490,11 @@ def _copy_part(hits, fragovl, fragfac):
     old info is overwritten
 
     @param[in,out] hits a list of blast_feature where the positions are sought
-    @param fragovl max fraction allowed that two hits overlap to be counted as 
+    @param fragovl max fraction allowed that two hits overlap to be counted as
          fragments
     @param[in] fragfac max factor by which fragments (ie parts) of one copy may
         differ in their score
-    @return index hits of each copy: idx[n][c] includes the list of hits 
+    @return index hits of each copy: idx[n][c] includes the list of hits
         belonging to copy c of gene n (c might be None)
     """
 
@@ -533,7 +529,7 @@ def _copy_part(hits, fragovl, fragfac):
     for h in hits:
         logging.debug("check %s " % (h))
 
-        if not h.name in predictions:
+        if h.name not in predictions:
             predictions[h.name] = []
 
         # check for each of the already determined copies if the current
