@@ -1,58 +1,56 @@
 '''
 @author: M. Bernt
-
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
 '''
 
 import glob
 import logging
 import os
 import re
-from shutil import rmtree
 import subprocess
+from shutil import rmtree
 from tempfile import mkdtemp
 
-from .. import feature
-from .. import mito
-from .. import trna
+from mitos import feature
+from mitos import mito
+from mitos import trna
 
 
 class InfernalException(Exception):
-
-    def __init__(self, value):
-        self.value = value
+    def __init__(self, command_line, exit_code, stderr):
+        self.command_line = command_line
+        self.exit_code = exit_code
+        self.stderr = stderr
 
     def __str__(self):
-        return repr(self.value)
+        return "command: %s exit code %s stderr %s" % (self.command_line, self.exit_code, self.stderr)
 
 
 def cmsearch(seqfile, outpath, code, refdir, evalue, sensitive, length, gl=True,
              RNAlist=None, trna=True, rrna=True, ori=True, intron=True, trnaovl=10, rrnaovl=10):
     """
-    run 
+    run
     1. cmsearch (infernal) on one given file using available models in refdir
     2. mitfi for the tRNAs and rRNAs
 
-    @param[in] seqfile input file name 
-    @param[in] outpath output file name 
-    @param[in] code genetic code table to use for tRNA naming 
+    @param[in] seqfile input file name
+    @param[in] outpath output file name
+    @param[in] code genetic code table to use for tRNA naming
     @param[in] refdir refdir directory containing reference data
-    @param[in] evalue evalue threshold to apply to cmsearch 
+    @param[in] evalue evalue threshold to apply to cmsearch
     @param[in] sensitive if true run cmsearch in sensitive mode
-    @param[in] length original sequence length to be used for e-value computation 
-    @param[in] gl if true then run cmsearch with option -g 
-    @param[in] RNAlist list of RNAs to check (e.g. "rrnS", "rrnL")  
-            - if this option is set only the specified models are run 
-            - trna or rrna must be set to true if mitfi should be run 
-              for tRNAs or rRNA   
+    @param[in] length original sequence length to be used for e-value computation
+    @param[in] gl if true then run cmsearch with option -g
+    @param[in] RNAlist list of RNAs to check (e.g. "rrnS", "rrnL")
+            - if this option is set only the specified models are run
+            - trna or rrna must be set to true if mitfi should be run
+              for tRNAs or rRNA
 
-    @param[in] trna iff True run mitfi for tRNA models 
+    @param[in] trna iff True run mitfi for tRNA models
     @param[in] rrna iff True run mitfi for rRNA models
     @param[in] ori iff True run mitfi on OL model
     @param[in] intron iff True run mitfi on intron models
     @param[in] trnaovl max overlap allowed between trna
-    @param[in] rrnaovl max overlap allowed between rrna 
+    @param[in] rrnaovl max overlap allowed between rrna
     """
 #     import inspect
 #     frame = inspect.currentframe()
@@ -97,7 +95,7 @@ def cmsearch(seqfile, outpath, code, refdir, evalue, sensitive, length, gl=True,
 
     # determine the models that should be run
     files = []
-    if RNAlist != None:
+    if RNAlist is not None:
         for r in RNAlist:
             files.append(
                 "{refdir}/ncRNA/{rna}.cm".format(refdir=refdir, rna=r))
@@ -151,7 +149,7 @@ def cmsearch(seqfile, outpath, code, refdir, evalue, sensitive, length, gl=True,
 #         print( " ".join( cmsargs + cmsargssen + [m, seqfile] ) )
         proc = subprocess.Popen(cmsargs + cmsargssen + [m, seqfile],
                                 stdout=subprocess.PIPE,
-                                stderr=subprocess.PIPE)
+                                stderr=subprocess.PIPE, universal_newlines=True)
         out, err = proc.communicate()
 
         if proc.returncode != 0 or len(err) > 0:
@@ -159,9 +157,9 @@ def cmsearch(seqfile, outpath, code, refdir, evalue, sensitive, length, gl=True,
             logging.error("for\n%s" %
                           (" ".join(cmsargs + cmsargssen + [m, seqfile])))
 
-            raise InfernalException(err)
+            raise InfernalException(" ".join(" ".join(cmsargs + cmsargssen + [m, seqfile]), proc.returncode, err))
         else:
-            f = open(outfile, "wb")
+            f = open(outfile, "w")
             f.write(out)
             f.close()
 
@@ -176,16 +174,16 @@ def cmsearch(seqfile, outpath, code, refdir, evalue, sensitive, length, gl=True,
         logging.debug(" ".join(mitfiargs + mitfi_spec[t]))
         proc = subprocess.Popen(mitfiargs + mitfi_spec[t],
                                 stdout=subprocess.PIPE,
-                                stderr=subprocess.PIPE)
+                                stderr=subprocess.PIPE, universal_newlines=True)
         out, err = proc.communicate()
 
         if proc.returncode != 0 or len(err) > 0:
             logging.error("mitfi exception\n%s\nfor %s" %
                           (err, " ".join(mitfiargs + mitfi_spec[t])))
-            raise InfernalException(err)
+            raise InfernalException(" ".join(mitfiargs + mitfi_spec[t]), proc.returncode, err)
         else:
             f = open("%s/%s_%sout.nc" %
-                     (outpath, os.path.basename(seqfile), t), "wb")
+                     (outpath, os.path.basename(seqfile), t), "w")
             f.write(out)
             f.close()
 
@@ -197,7 +195,7 @@ def cmsearch(seqfile, outpath, code, refdir, evalue, sensitive, length, gl=True,
 #         logging.debug( " ".join( mitfiargs + mitfitRNA ) )
 #         proc = subprocess.Popen( mitfiargs + mitfitRNA, \
 #                                      stdout = subprocess.PIPE, \
-#                                      stderr = subprocess.PIPE )
+#                                      stderr = subprocess.PIPE, universal_newlines=True )
 #         out, err = proc.communicate()
 #         if proc.returncode != 0 or len( err ) > 0:
 #             logging.error( "mitfi exception\n%s" % err )
@@ -213,7 +211,7 @@ def cmsearch(seqfile, outpath, code, refdir, evalue, sensitive, length, gl=True,
 #         logging.debug( " ".join( mitfiargs + mitfirRNA ) )
 #         proc = subprocess.Popen( mitfiargs + mitfirRNA , \
 #                                      stdout = subprocess.PIPE, \
-#                                      stderr = subprocess.PIPE )
+#                                      stderr = subprocess.PIPE, universal_newlines=True)
 #         out, err = proc.communicate()
 #         if proc.returncode != 0 or len( err ) > 0:
 #             logging.error( "mitfi exception\n%s" % err )
@@ -262,11 +260,11 @@ def cmrealign(sequence, rRNA, refdir):
 
     logging.debug(" ".join(args))
     proc = subprocess.Popen(
-        args, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+        args, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True)
     out, err = proc.communicate()
     if proc.returncode != 0 or len(err) > 0:
         logging.error("cmalign exception\n%s" % err)
-        raise InfernalException(err)
+        raise InfernalException(" ".join(args), proc.returncode, err)
     else:
         f = open("%s/cmrealign.out" % tdir, "w")
         f.write(str(out))
@@ -278,7 +276,7 @@ def cmrealign(sequence, rRNA, refdir):
     # improve structure
     proc = subprocess.Popen(["java", "-jar", mitfiimppath, tdir, "%s/cmrealign.stk" % (tdir)],
                             stdout=subprocess.PIPE,
-                            stderr=subprocess.PIPE)
+                            stderr=subprocess.PIPE, universal_newlines=True)
     out, err = proc.communicate()
     if proc.returncode != 0 or len(err) > 0:
         logging.error("improve_infernal_structure exception\n%s" % err)
@@ -301,7 +299,7 @@ def mitfi(fastafiles, offsets,
           outpath, code, refdir, evalue, sensitive, length, gl=True,
           RNAlist=None, trna=True, rrna=True, ori=True, intron=True, trnaovl=10, rrnaovl=10):
     """
-    wrapper calling 
+    wrapper calling
     1. cmserach
     2. parse
     for a list of offsets. returned positions are corrected for the offset.
@@ -339,7 +337,7 @@ def remove_empty(trna, rrna, ori, intron, rnalist, mitfipath, offsets):
     @param[in] mitfipath the path to delete the cmoutput in
     @param[in] offsets the offsets to remove the empty files
 
-    @return True iff something was removed 
+    @return True iff something was removed
     """
 
     ret = False
@@ -393,11 +391,11 @@ def parse(inpath, seqfile, incl_trna, incl_rrna, incl_ori, incl_intron, minmito=
     parses all mitfifiles in a given directory and returns list of features
     @parm inpath filehandler mitfifile
     @param seqfile get only the mitfi output from the results belonging to seqfile
-    @param trna accept trnas 
+    @param trna accept trnas
     @param rrna accept rrna
     @param intron accept introns
     @param minmito minimum value of the mito property to accept a feature
-    @return feature list 
+    @return feature list
     """
 
     features = []
@@ -440,11 +438,11 @@ def parse(inpath, seqfile, incl_trna, incl_rrna, incl_ori, incl_intron, minmito=
 
                 # TODO: this regex is a workaround to the new model names
                 # which are not correctly treated by mitfi
-                mt = re.match("trn(\w\d*)", cols[13])
-                mr = re.match("(rrn[SL])", cols[13])
-                if mt != None:
+                mt = re.match(r"trn(\w\d*)", cols[13])
+                mr = re.match(r"(rrn[SL])", cols[13])
+                if mt is not None:
                     name = mt.group(1)
-                elif mr != None:
+                elif mr is not None:
                     name = mr.group(1)
                 else:
                     name = cols[13]  # amino acid name
@@ -523,7 +521,7 @@ def parse_feature(inpath, seqfile, local, name, start, stop, strand):
     """
     get a certain feature from the mitfi file
 
-    @param name name of the feature 
+    @param name name of the feature
     @param start start position of the feature
     @param stop stop position of the feature
     @param strand strand of the feature
