@@ -1,18 +1,13 @@
 '''
 @author: M. Bernt
-
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
-
 '''
-from __future__ import print_function
 
-from optparse import OptionParser
 import glob
-import sys
 import os
+import sys
+from optparse import OptionParser
 
-from gb import gbfromfile
+from mitos.gb import gbfromfile
 
 
 usage = "usage: %prog dir"
@@ -22,7 +17,7 @@ parser.add_option("-d", "--dir", action="store", type="string",
                   metavar="DIR", help="directory with *.gb files")
 (options, args) = parser.parse_args()
 
-if options.dir == None:
+if options.dir is None:
     print("no input directory given")
     print(usage)
     sys.exit(1)
