@@ -8,19 +8,18 @@ import glob
 import logging
 import math
 import os
-import sys
-from Bio.Seq import Seq
-import random
 import subprocess
 
-from ..bedfile import bedwriter
-from ..blast import position_values, _improve_start_stop, _improve_start_stop_old
-from ..blast import _create_protplotdata
-from .. import feature
-from ..gb import gbfromfile
-from ..mergefeature import _copy_part
-from .. import mito
-from .. import sequence
+from mitos import feature
+from mitos import mito
+from mitos import sequence
+from mitos.blast import (
+    _create_protplotdata,
+    _improve_start_stop,
+    _improve_start_stop_old,
+    position_values
+)
+from mitos.mergefeature import _copy_part
 
 
 def create_blast_feature(gene, seqstart, seqstop, strand, score, evalue, rf, hmstart, hmstop, mlen, method='mitos', tpe='gene'):
@@ -73,7 +72,7 @@ def hmmscan_call(seqfile, gene, dbfile, tmpDir):
            "--noali", "--domtblout", outFile, dbfile, seqfile]
     logging.debug("%s" % (" ".join(cmd)))
     proc = subprocess.Popen(cmd, stdout=subprocess.PIPE,
-                            stderr=subprocess.PIPE)
+                            stderr=subprocess.PIPE, universal_newlines=True)
     out, err = proc.communicate()
 
     if proc.returncode != 0 or len(err) > 0:
@@ -154,10 +153,9 @@ def get_best_hits(mergedF, gene, seqLen, evalTh, finovl, circular):
         overlap = False
 
         t = create_blast_feature(gene, seqstart=d['nuc_s'], seqstop=d['nuc_e'],
-                                 strand=d['strand'], score=d[
-                                     'bits'], evalue=d['evalue'],
-                                 rf=d['frame'], hmstart=d[
-                                     'mstart'], hmstop=d['mend'],
+                                 strand=d['strand'], score=d['bits'],
+                                 evalue=d['evalue'], rf=d['frame'],
+                                 hmstart=d['mstart'], hmstop=d['mend'],
                                  mlen=d['mlen'])
 
         if t.length(circular, seqLen) % 3 != 0:
@@ -169,34 +167,34 @@ def get_best_hits(mergedF, gene, seqLen, evalTh, finovl, circular):
                 overlap = True
                 break
 
-        if overlap == False:
+        if overlap is False:
             featlist.append(t)
 
     return featlist
 
 
-def get_nuc_pos(frame, s, end, l):
+def get_nuc_pos(frame, start, end, length):
     """
     function to transform amino acid position to nucleotide position
     @param frame frame from 0 to 5. 0 is +1 frame, 1 is -1, 2 is +2 ...
-    @param s start of hit in amino acid position
+    @param start start of hit in amino acid position
     @param end end of hit in amino acid position
-    @param l length of the genome
+    @param length length of the genome
     """
 
     # make coordinates 0 based
-    s -= 1
+    start -= 1
     end -= 1
 
     # positive frames
     if frame < 3:
-        nuc_s = 3 * s + frame
+        nuc_s = 3 * start + frame
         nuc_e = 3 * (end + 1) - 1 + frame
 
     # negative frames
     else:
-        nuc_s = l - 1 - (3 * (end + 1) - 1) - (frame - 3)
-        nuc_e = l - 1 - (3 * s) - (frame - 3)
+        nuc_s = length - 1 - (3 * (end + 1) - 1) - (frame - 3)
+        nuc_e = length - 1 - (3 * start) - (frame - 3)
     return nuc_s, nuc_e
 
 #     01234567890123    l=14
@@ -241,15 +239,11 @@ def get_strand(frame):
 
 
 def get_transtable(fname):
-    l = []
     with open(fname, 'r') as inF:
         for line in inF:
             if '/transl_table' in line:
-                l = line.split('=')
-
-                return int(l[1])
-        if not l:
-            return 1
+                return int(line.split('=')[1])
+    return 1
 
 
 def merge_frames(gene, fList, tmpDir):
@@ -293,7 +287,7 @@ def prot_feat_wrap(fastafiles, offsets, filepath,
     @param fastafiles list of fastafiles, 1 per offset
     @param offsets list of offsets for the fastafiles
     @param filepath
-    @param circular 
+    @param circular
     @param startcod start codon statistics
     @param stopcod stop codon statistics
     @param len_pval a dictionary containing for each gene the length pvalues
@@ -354,7 +348,7 @@ def prot_feat_wrap(fastafiles, offsets, filepath,
         # correct the idx and the values for the offset
         logging.debug("offset %d" % (offsets[i]))
         for n in oidx:  # names
-            if not n in idx:
+            if n not in idx:
                 idx[n] = dict()
 
             for of in oidx[n]:  # frames
@@ -364,7 +358,7 @@ def prot_feat_wrap(fastafiles, offsets, filepath,
                     f = math.copysign(
                         ((abs(of) - 1) + (offsets[i] % 3)) % 3 + 1, of)
 
-                if not f in idx[n]:
+                if f not in idx[n]:
                     idx[n][f] = dict()
 
                 for op in oidx[n][of]:  # positions
@@ -461,7 +455,7 @@ def prot_feat(seq, code, startcod, stopcod, len_pval, trnas, idx, values, refdir
     # analogously to blast based methods
     f = open("%s/stst.dat" % (tmpDir), "w")
     for n in cpyprt:
-        if not n in idx:
+        if n not in idx:
             idx[n] = {}
         for cpy in cpyprt[n]:
             if cpyprt[n][cpy][0].type != "gene":
