@@ -1,19 +1,14 @@
 '''
 @author: M. Bernt
-
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
 '''
 
-from __future__ import print_function
 import os
-import os.path
 import re
 import subprocess
-import sys
+from sys import stderr
 
 
-from .. import extprog
+from mitos import extprog
 
 
 def is_valid_bp(a, b):
@@ -46,14 +41,14 @@ class rna:
     def load_dotbracket(self, db):
         """
         load a dot bracket representation
-        \param db the dot bracket representation
+        @param db the dot bracket representation
         """
 #        print "loading rna ", db
         self.db = ""
         self.bp = []
         stack = []
 
-        for i in xrange(len(db)):
+        for i in range(len(db)):
             if db[i] == '(':
                 stack.append(i)
             elif db[i] == ')':
@@ -137,13 +132,13 @@ class rna:
 def RNAalifold(alnfile, alifname, alifoldf=None, alirnaf=None, alidotf=None, alnf=None, constraints=None, **keywords):
     """
     call RNAalifold
-    \param alnfile alignment file for input
-    \param alifname filename for the output of RNAalifold
-    \param alifoldf filename for alifold.out (only produced with -p), if None then the file will be deleted 
-    \param alirnaf filename for the alirna.ps file (produced per default), if None then the file will be deleted
-    \param alidotf filename for the alidot.ps file (only produced with -p), if None then the file will be deleted 
-    \param alnf filename for the aln.ps file (only produced with -aln), if None then the file will be deleted 
-    \param constraints name of the constraints file 
+    @param alnfile alignment file for input
+    @param alifname filename for the output of RNAalifold
+    @param alifoldf filename for alifold.out (only produced with -p), if None then the file will be deleted
+    @param alirnaf filename for the alirna.ps file (produced per default), if None then the file will be deleted
+    @param alidotf filename for the alidot.ps file (only produced with -p), if None then the file will be deleted
+    @param alnf filename for the aln.ps file (only produced with -aln), if None then the file will be deleted
+    @param constraints name of the constraints file
 
     -cv factor
         Set the weight of the covariance term in the energy function to factor. Default is 1.
@@ -172,25 +167,25 @@ def RNAalifold(alnfile, alifname, alifoldf=None, alirnaf=None, alidotf=None, aln
     cl = extprog.cmdline(keywords, stdpar, alifoldpar)
     pars = str(cl) + alnfile
 
-    if cl.get("C") != None:
-        if constraints == None:
-            raise Exception("RNAalifold -C but no constraints file given")
+    if cl.get("C") is not None:
+        if constraints is None:
+            raise Exception("RNAalifold: -C but no constraints file given")
         cfile = open(constraints, "r")
 #    print "alifold parameters ", pars
     p = subprocess.Popen("RNAalifold %s" % (pars), shell=True, stdout=subprocess.PIPE,
-                         stderr=subprocess.PIPE, stdin=subprocess.PIPE, close_fds=True)
-    if cfile != None:
+                         stderr=subprocess.PIPE, stdin=subprocess.PIPE, close_fds=True, universal_newlines=True)
+    if cfile is not None:
         p.stdin.write(cfile.read())
 
-    if cl.get("C") != None:
+    if cl.get("C") is not None:
         cfile.close()
 
     err = ""
-    for i in p.stderr.readlines():
-        if i == "" or re.match("^\\d+ sequences; length of alignment \\d+\.$", i) != None:
+    for line in p.stderr.readlines():
+        if line == "" or re.match(r"^\d+ sequences; length of alignment \d+\.$", line) is not None:
             continue
         else:
-            err += i + "\n"
+            err += line + "\n"
 
     if err != "":
         raise extprog.StderrError("RNAalifold %s" % pars, err)
@@ -201,42 +196,42 @@ def RNAalifold(alnfile, alifname, alifoldf=None, alirnaf=None, alidotf=None, aln
 
     # rename / delete alifold.out
     if os.path.exists("alifold.out"):
-        if alifoldf == None:
+        if alifoldf is None:
             os.remove("alifold.out")
         else:
             os.rename("alifold.out", str(alifoldf))
-    elif alifoldf != None:
+    elif alifoldf is not None:
         print("warning: RNAalifold did not produced a alifold.out file")
-        if cl.get('p') == None:
+        if cl.get('p') is None:
             print("         you have to enable parameter -p")
 
     # rename / delete the various ps outputs
     if os.path.exists("alirna.ps"):
-        if alirnaf == None:
+        if alirnaf is None:
             os.remove("alirna.ps")
         else:
             os.rename("alirna.ps", str(alirnaf))
-    elif alirnaf != None:
+    elif alirnaf is not None:
         print("warning: RNAalifold did not produced a alirna.ps file")
 
     if os.path.exists("alidot.ps"):
-        if alidotf == None:
+        if alidotf is None:
             os.remove("alidot.ps")
         else:
             os.rename("alidot.ps", str(alidotf))
-    elif alidotf != None:
+    elif alidotf is not None:
         print("warning: RNAalifold did not produced a alidot.ps file")
-        if cl.get('p') == None:
+        if cl.get('p') is None:
             print("         you have to enable parameter -p")
 
     if os.path.exists("aln.ps"):
-        if alnf == None:
+        if alnf is None:
             os.remove("aln.ps")
         else:
             os.rename("aln.ps", str(alnf))
-    elif alnf != None:
+    elif alnf is not None:
         print("warning: RNAalifold did not produced a aln.ps file")
-        if cl.get('aln') == None:
+        if cl.get('aln') is None:
             print("         you have to enable parameter -aln")
 
     return
@@ -245,9 +240,9 @@ def RNAalifold(alnfile, alifname, alifoldf=None, alirnaf=None, alidotf=None, aln
 def RNAalifold_parse(alifname, alifoldf=None):
     """
     parse the result file of RNAalifold
-    \param alifname name of the file conatining the stdout of RNAalifold
-    \param alifoldf name of the file conatining the alifold.out contents, if None -> ignored
-    \return dict containing the keys 'seq', 'mfe', and 'pf'; seq contains just the sequence which is folded; 
+    @param alifname name of the file conatining the stdout of RNAalifold
+    @param alifoldf name of the file conatining the alifold.out contents, if None -> ignored
+    @return dict containing the keys 'seq', 'mfe', and 'pf'; seq contains just the sequence which is folded;
     mfe contains the mfe-structure 'str', the energy 'nrg', as well as the energy components :
     'mnrg' mfe contribution and 'snrg' sequence contribution
     """
@@ -265,25 +260,25 @@ def RNAalifold_parse(alifname, alifoldf=None):
 # not match up.
 
     pairs = []
-    if alifoldf != None:
+    if alifoldf is not None:
         f = open(alifoldf, "r")
-        for l in f.readlines():
-            if re.match("^\\s*\\d+ sequence; length of alignment \\d+\\s*$", l) != None:
+        for line in f.readlines():
+            if re.match(r"^\s*\d+ sequence; length of alignment \d+\s*$", line) is not None:
                 continue
-            if re.match("^alifold output$", l) != None:
+            if re.match(r"^alifold output$", line) is not None:
                 continue
-            if re.match("^([\.,\|\{\}\(\)]+)\\s*$", l) != None:
+            if re.match(r"^([\.,\|\{\}\(\)]+)\s*$", line) is not None:
                 continue
 
-            l = l.strip().split()
-            pairs.append({'start': int(l[0]), 'end': int(l[1]), 'incomp': int(
-                l[2]), 'prob': float(l[3][:-1]), 'entropy': float(l[4]), 'bp': []})
-            for i in range(5, len(l)):
-                if l[i] == '+':
+            line = line.strip().split()
+            pairs.append({'start': int(line[0]), 'end': int(line[1]), 'incomp': int(
+                line[2]), 'prob': float(line[3][:-1]), 'entropy': float(line[4]), 'bp': []})
+            for i in range(5, len(line)):
+                if line[i] == '+':
                     continue
-                pairs[-1]['bp'].append((l[i][:2], int(l[i][3:])))
+                pairs[-1]['bp'].append((line[i][:2], int(line[i][3:])))
 
-            if l[-1] == '+':
+            if line[-1] == '+':
                 pairs[-1]['inmfe'] = True
             else:
                 pairs[-1]['inmfe'] = False
@@ -293,18 +288,18 @@ def RNAalifold_parse(alifname, alifoldf=None):
     f = open(alifname, "r")
 
     results = {}
-    for l in f.readlines():
-        if l == "":
+    for line in f.readlines():
+        if line == "":
             continue
 
-        m = re.match("^([_ACGTUXagctux]+)$", l)
-        if m != None:
+        m = re.match(r"^([_ACGTUXagctux]+)$", line)
+        if m is not None:
             results['seq'] = m.group(1)
             continue
 
         m = re.match(
-            "^([\.\(\)]+)\\s*\(\\s*([-.\\d]+)\\s*=\\s*(\\s*[-.\\d]+)\\s*\+\\s*([-.\\d]+)\\s*\)\\s*$", l)
-        if m != None:
+            r"^([\.\(\)]+)\s*\(\s*([-.\d]+)\s*=\s*(\s*[-.\d]+)\s*\+\s*([-.\d]+)\s*\)\s*$", line)
+        if m is not None:
             results['mfe'] = {}
             results['mfe']['str'] = m.group(1)
             results['mfe']['nrg'] = float(m.group(2))
@@ -313,15 +308,15 @@ def RNAalifold_parse(alifname, alifoldf=None):
 
             continue
 
-        m = re.match("^([\.,\|\{\}\(\)]+)\\s+\[\\s*([+-\.\\d]+)\\s*\]\\s*$", l)
-        if m != None:
+        m = re.match(r"^([\.,\|\{\}\(\)]+)\s+\[\s*([+-\.\d]+)\s*\]\s*$", line)
+        if m is not None:
             results['pf'] = {}
             results['pf']['str'] = m.group(1)
             results['pf']['nrg'] = m.group(2)
             results['pf']['pairs'] = pairs
             continue
 
-        print("RNAalifold_parse: ", l)
+        print("RNAalifold_parse: ", line)
     f.close()
 
     return results
@@ -330,10 +325,10 @@ def RNAalifold_parse(alifname, alifoldf=None):
 def RNAeval(sequences, structures, **keywords):
     """
     call RNAeval [-T temp] [-4] [-d[0|1|2|3]]  [-e 1|2] [-P paramfile] [-circ] [-noconv] [-logML]
-    \param sequences a list of sequences / one sequence
-    \param structures a list of structures / one structure
-    \param keywords parameters for RNAeval
-    \return list of energy values
+    @param sequences a list of sequences / one sequence
+    @param structures a list of structures / one structure
+    @param keywords parameters for RNAeval
+    @return list of energy values
     """
     # print sequences
     # print structures
@@ -349,26 +344,25 @@ def RNAeval(sequences, structures, **keywords):
     if isinstance(structures, str):
         structures = [structures]
 
-    inp = ""
+    input = ""
     if len(sequences) == 1 and len(structures) > 1:
         for i in range(len(structures)):
-            inp += sequences[0] + "\n" + structures[i] + "\n"
+            input += sequences[0] + "\n" + structures[i] + "\n"
     elif len(sequences) > 1 and len(structures) == 1:
         for i in range(len(sequences)):
-            inp += sequences[i] + "\n" + structures[0] + "\n"
+            input += sequences[i] + "\n" + structures[0] + "\n"
     elif len(sequences) == len(structures):
         for i in range(len(sequences)):
-            inp += sequences[i] + "\n" + structures[i] + "\n"
+            input += sequences[i] + "\n" + structures[i] + "\n"
     else:
-        raise Exception(
-            "RNAeval need equal number of sequences and structures or one of them has to be single")
-    inp += "@\n"
+        raise Exception("RNAeval: need equal number of sequences and structures or one of them has to be single")
+    input += "@\n"
 
     cl = extprog.cmdline(keywords, evalpar)
     pars = str(cl)
     p = subprocess.Popen("RNAeval %s" % (pars), shell=True, stdin=subprocess.PIPE,
-                         stdout=subprocess.PIPE, stderr=subprocess.PIPE, close_fds=True)
-    p.stdin.write(inp)
+                         stdout=subprocess.PIPE, stderr=subprocess.PIPE, close_fds=True, universal_newlines=True)
+    p.stdin.write(input)
     p.stdin.close()
     p.wait()
 
@@ -377,19 +371,19 @@ def RNAeval(sequences, structures, **keywords):
     nerr = []
     for e in err:
         m = re.match(
-            "^WARNING: bases [0-9]+ and [0-9]+ \(..\) can't pair!$", e)
-        if m == None:
+            r"^WARNING: bases [0-9]+ and [0-9]+ \(..\) can't pair!$", e)
+        if m is None:
             nerr.append(e)
 
     err = "".join(nerr)
     if err != "":
-        sys.stderr.write(
-            "RNAeval returned an error message for:\n%s\n%s\n" % (inp, err))
+        stderr.write(
+            "RNAeval returned an error message for:\n%s\n%s\n" % (input, err))
 
     results = []
-    for l in p.stdout.readlines():
-        m = re.match("[\.\(\)]+\\s+\(\\s*([-\.\\d]+)\)", l)
-        if m != None:
+    for line in p.stdout.readlines():
+        m = re.match(r"[\.\(\)]+\s+\(\s*([-\.\d]+)\)", line)
+        if m is not None:
             results.append(float(m.group(1)))
 
     return results
@@ -401,16 +395,16 @@ def RNALfold(sequence, **keywords):
     return a list of 3-tuples (structure, energy, position)
     """
 
-    st = re.compile("^([\(\)\.]+)\\s\(\\s*([\-0-9\.]+)\)\\s+(\\d+)\\s*$")
-    sq = re.compile("^\\S+$")
-    en = re.compile("^\\s*\(\\s*([\-0-9\.]+)\)\\s*$")
+    st = re.compile(r"^([\(\)\.]+)\s\(\s*([\-0-9\.]+)\)\s+(\d+)\s*$")
+    sq = re.compile(r"^\S+$")
+    en = re.compile(r"^\s*\(\s*([\-0-9\.]+)\)\s*$")
 
     par = [extprog.shortparm('L', 'int'), extprog.shortparm('T', 'float'), extprog.shortparm('noGU', 'flag'), extprog.shortparm('noCloseGU', 'flag'),
            extprog.shortparm('e', 'int', [1, 2]), extprog.shortparm('P', 'file'), extprog.shortparm('nsp', 'string')]
     cl = str(extprog.cmdline(keywords, par))
 
     p = subprocess.Popen("RNALfold %s" % (cl), shell=True, stdin=subprocess.PIPE,
-                         stdout=subprocess.PIPE, stderr=subprocess.PIPE, close_fds=True)
+                         stdout=subprocess.PIPE, stderr=subprocess.PIPE, close_fds=True, universal_newlines=True)
 
     p.stdin.write(sequence + "\n")
     p.stdin.write("@\n")
@@ -420,25 +414,25 @@ def RNALfold(sequence, **keywords):
     structures = []
     minenergy = 0.0
 
-    for l in p.stdout.readlines():
-        if len(l) == 0 or l[0] == '>':
+    for line in p.stdout.readlines():
+        if len(line) == 0 or line[0] == '>':
             continue
 
-        m = st.match(l)
-        if m != None:
+        m = st.match(line)
+        if m is not None:
             #            print "structure"
             structures.append((m.group(1), float(m.group(2)), int(m.group(3))))
             continue
-        m = sq.match(l)
-        if m != None:
-            #            print "sequence ", l
+        m = sq.match(line)
+        if m is not None:
+            #            print "sequence ", line
             continue
-        m = en.match(l)
-        if m != None:
-            #            print "energy   ", l
+        m = en.match(line)
+        if m is not None:
+            #            print "energy   ", line
             minenergy = float(m.group(1))
             continue
-        print("NO MATCH ", l)
+        print("NO MATCH ", line)
 
 #    for s in structures:
 #        print s
@@ -459,25 +453,25 @@ def RNAplot(sequence, structure, fname, **keywords):
     pars = str(cl)
 
     p = subprocess.Popen("cd %s; RNAplot %s; cd -;" % (os.path.dirname(fname), pars), shell=True,
-                         stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE, close_fds=True)
-    p.stdin.write((sequence + "\n").encode("utf-8"))
-    p.stdin.write((structure + "\n").encode("utf-8"))
-    p.stdin.write("@\n".encode("utf-8"))
+                         stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE, close_fds=True, universal_newlines=True)
+    p.stdin.write(sequence + "\n")
+    p.stdin.write(structure + "\n")
+    p.stdin.write("@\n")
     p.stdin.close()
     p.wait()
 
-    if cl.get("o") != None:
+    if cl.get("o") is not None:
         ext = cl.get("o")
     else:
         ext = "ps"
 
     if os.path.exists("%s/rna.%s" % (os.path.dirname(fname), ext)):
         os.rename("%s/rna.%s" % (os.path.dirname(fname), ext), fname)
-    elif fname != None:
+    elif fname is not None:
         print("warning: RNAplot did not produced a %s file" % (ext))
-        for l in p.stderr.readlines():
-            print("stderr", l.strip())
-        for l in p.stdout.readlines():
-            print("stdout", l.strip())
+        for line in p.stderr.readlines():
+            print("stderr", line.strip())
+        for line in p.stdout.readlines():
+            print("stdout", line.strip())
 
     return
