@@ -1,22 +1,20 @@
 '''
 @author: M. Bernt
-
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
 '''
-import logging
 from random import randint, shuffle
-from sys import stdout, stderr, exit
+from sys import stdout
 
-from Bio.Seq import Seq, translate
-from Bio import Alphabet
+from Bio import (
+    Alphabet,
+    Data,
+    SeqIO
+)
+from Bio.Alphabet import _verify_alphabet as verify_alphabet
 from Bio.Alphabet.IUPAC import ambiguous_dna
-try:
-    from Bio.Alphabet import _verify_alphabet as verify_alphabet
-except:  # for old biopython
-    from Bio.utils import verify_alphabet
-from Bio import Data
-from Bio import SeqIO
+from Bio.Seq import (
+    Seq,
+    translate
+)
 from Bio.SeqRecord import SeqRecord
 
 
@@ -46,7 +44,7 @@ class MultiFastaException(Exception):
 
 class AlphabetException(Exception):
     """
-    Exception to be raised when the alphabet does not match the sequence 
+    Exception to be raised when the alphabet does not match the sequence
     """
 
     def __init__(self, seq, alpha):
@@ -72,7 +70,7 @@ class sequence(Seq):
 
     def __init__(self, data, alphabet=Alphabet.IUPAC.IUPACAmbiguousDNA(), circular=False, upper=False):
         """
-        @param[in] upper if true: transform each letter to upper case, else: leave as is 
+        @param[in] upper if true: transform each letter to upper case, else: leave as is
         """
 
         data = data.strip().upper()
@@ -82,7 +80,6 @@ class sequence(Seq):
         if not verify_alphabet(self):
             raise AlphabetException(str(self), alphabet)
 
-
 #    def __neq__( self, other ):
 #        """
 #        check two sequences for inequality
@@ -122,11 +119,11 @@ class sequence(Seq):
         """
         shift the sequence by other (int) to the left
         """
-        if (type(other) != type(0)):
-            raise TypeError, "sequence shift with " + \
-                repr(other) + " " + repr(type(other)) + " is impossible"
-        if (self.circular == False):
-            raise TypeError, "sequence shift of linear sequence is impossible"
+        if not isinstance(other, int):
+            raise TypeError("sequence shift with "
+                + repr(other) + " " + repr(type(other)) + " is impossible")
+        if (self.circular is False):
+            raise TypeError("sequence shift of linear sequence is impossible")
 
         rdata = "".join([self[(i + other) % len(self)]
                          for i in range(len(self))])
@@ -136,11 +133,11 @@ class sequence(Seq):
         """
         shift the sequence by other (int) to the right
         """
-        if (type(other) != type(0)):
-            raise TypeError, "sequence shift with " + \
-                repr(other) + " " + repr(type(other)) + " is impossible"
-        if (self.circular == False):
-            raise TypeError, "sequence shift of linear sequence is impossible"
+        if not isinstance(other, int):
+            raise TypeError("sequence shift with "
+                + repr(other) + " " + repr(type(other)) + " is impossible")
+        if (self.circular is False):
+            raise TypeError("sequence shift of linear sequence is impossible")
 
         rdata = "".join([self[(i - other) % len(self)]
                          for i in range(len(self))])
@@ -149,8 +146,8 @@ class sequence(Seq):
     def dinucleotide_count(self, osb=True):
         """
         get the dinucleotide count of the sequence
-        \param osb if true consider only standard bases (ATCG)
-        \return a dictionary containing the counts 
+        param osb if true consider only standard bases (ATCG)
+        return a dictionary containing the counts
         """
         dn = {}
 
@@ -158,7 +155,7 @@ class sequence(Seq):
             for sb2 in Data.IUPACData.unambiguous_dna_letters:
                 dn[sb1 + sb2] = 0.0
 
-        for i in xrange(len(self)):
+        for i in range(len(self)):
             if not self.circular and (i + 1) >= len(self):
                 continue
 
@@ -173,8 +170,8 @@ class sequence(Seq):
     def dinucleotide_frequency(self, osb=True):
         """
         get the dinucleotide count of the sequence
-        \param osb if true consider only standard bases (ATCG)
-        \return a dictionary containing the frequencies
+        param osb if true consider only standard bases (ATCG)
+        return a dictionary containing the frequencies
         """
         dn = self.dinucleotide_count(osb)
         if self.circular:
@@ -188,6 +185,12 @@ class sequence(Seq):
 
         return dn
 
+    def isambig(self):
+        if 'N' in str(self):
+            return True
+        else:
+            return False
+
     def isequal(self, other, maxac=None):
         """
         check two sequences for equality
@@ -197,7 +200,7 @@ class sequence(Seq):
         - same data (ambiguities are checkes, i.e. N=A, ...)
         @param self seq
         @param other another seq
-        @param maxac maximum number of allowed ambigous positions (in either sequence) 
+        @param maxac maximum number of allowed ambigous positions (in either sequence)
         """
 
         if not isinstance(self, sequence) or not isinstance(other, sequence):
@@ -224,12 +227,12 @@ class sequence(Seq):
 
             try:
                 oa = set(ambiguous_nucleotide_values[other[i]])
-            except:
+            except KeyError:
                 oa = set()
 
             try:
                 sa = set(ambiguous_nucleotide_values[self[i]])
-            except:
+            except KeyError:
                 sa = set()
 
             if self[i] == other[i]:
@@ -245,7 +248,7 @@ class sequence(Seq):
                 return False
 #         print "RETURN TRUE"
 
-        if maxac != None and ac > maxac:
+        if maxac is not None and ac > maxac:
             return False
         else:
             return True
@@ -260,7 +263,7 @@ class sequence(Seq):
         for sb in Data.IUPACData.unambiguous_dna_letters:
             nc[sb] = 0.0
 
-        for i in xrange(len(self)):
+        for i in range(len(self)):
             if osb and (self[i] not in Data.IUPACData.unambiguous_dna_letters):
                 continue
             if not self[i] in nc:
@@ -285,7 +288,7 @@ class sequence(Seq):
 
     def shuffle(self):
         """
-        random shuffle the sequence 
+        random shuffle the sequence
         """
         tdata = [x for x in self.data]
         shuffle(tdata)
@@ -297,8 +300,8 @@ class sequence(Seq):
         note: subsequences are always linear
 
         @param start start index, note counting starts at 0
-        @param stop end index, note element at the stop index is included in the sequence  
-        @param strand +1/-1 get the reverse complement of the sequence if -1 and the sequence if 1 
+        @param stop end index, note element at the stop index is included in the sequence
+        @param strand +1/-1 get the reverse complement of the sequence if -1 and the sequence if 1
         """
 
         if strand != 1 and strand != -1:
@@ -347,12 +350,12 @@ class sequence(Seq):
 
     def start_stop_subsequence(self, transl_table, mx=False):
         """
-        get (start,stop, strand) tuples of the sequence such that at start is a 
+        get (start,stop, strand) tuples of the sequence such that at start is a
         start codon and at end a end codon
-        \param transl_table the id of the translation table
-        \param mx only return maximal sequences, i.e. if there are two sequences 
+        param transl_table the id of the translation table
+        param mx only return maximal sequences, i.e. if there are two sequences
         (s1,e) and (s2,e) with s1<s2 then only (s1,e) will be returned
-        \todo subsequences crossing the 0 .. attention the reading frame calculations 
+        todo subsequences crossing the 0 .. attention the reading frame calculations
         get tricky
         """
 
@@ -379,7 +382,7 @@ class sequence(Seq):
                 stack[i % 3] = []
 
         # first -strand
-        if self.circular == False:
+        if self.circular is False:
             return ret
 
         stack = [[], [], []]
@@ -410,7 +413,7 @@ class sequence(Seq):
 
     def deambig(self):
         """
-        return a list of sequences 
+        return a list of sequences
         """
         # print "deambig"
         if self.alphabet == Alphabet.IUPAC.ambiguous_dna or self.alphabet == Alphabet.IUPAC.unambiguous_dna:
@@ -449,12 +452,12 @@ class randsequence(sequence):
     def __init__(self, length, alphabet=Alphabet.IUPAC.IUPACUnambiguousDNA(), circular=False):
         """
         generate a random sequence of a certain alphabet
-        \param length how long should the sequence be
-        \param alphabet which alphabet 
-        \param circular init as circular
+        param length how long should the sequence be
+        param alphabet which alphabet
+        param circular init as circular
         """
         data = []
-        for i in xrange(length):
+        for i in range(length):
             data.append(
                 alphabet.letters[randint(0, len(alphabet.letters) - 1)])
         data = "".join(data).strip().upper()
@@ -529,7 +532,7 @@ def seqlistmaker(sequence, start, stop, strand, acc, name="", code=None, seqlist
     @param stop the stop of the part
     @param acc the acc of the species
     @param name the name of the part if ther is a name.
-    @param code translate with code, do not translate if None 
+    @param code translate with code, do not translate if None
     @param seqlist A list of sequences, online needet if this sequenz is only a part of bigger list.
 
     This method cut a part of a big sequence and append it in a list.
@@ -556,7 +559,7 @@ def seqlistmaker(sequence, start, stop, strand, acc, name="", code=None, seqlist
     # set the subsequnc, need a Bio.Seq.Seq format
     mito_frag = sequence.subseq(start, stop, int(strand))
 
-    if code != None:
+    if code is not None:
         mito_frag = Seq(mito_frag.translate(table=code))
 
     # Set record with header
@@ -582,7 +585,7 @@ def fastawriter(featurelist, sequence, code, acc, outputtype, outfile=None, mode
     if isinstance(outfile, str):
         with open(outfile, mode) as f:
             SeqIO.write(seqlist, f, "fasta")
-    elif outfile == None:
+    elif outfile is None:
         SeqIO.write(seqlist, stdout, "fasta")
     else:
         SeqIO.write(seqlist, outfile, "fasta")
@@ -598,11 +601,11 @@ def fastawriter(featurelist, sequence, code, acc, outputtype, outfile=None, mode
 #    seq = ""
 #    for line in lines:
 #        if line.startswith( ">" ):
-#            if header == None:
+#            if header is None:
 #                header = line[1:].strip()
 #            else:
 #                raise MultiFastaException()
-#        elif header != None:
+#        elif header is not None:
 #            line = line.upper().strip()
 #            if len( line ) > 0:
 #                if line[0] in Alphabet.IUPAC.IUPACAmbiguousDNA().letters:
@@ -613,7 +616,7 @@ def fastawriter(featurelist, sequence, code, acc, outputtype, outfile=None, mode
 #                    raise AlphabetException( line, Alphabet.IUPAC.IUPACAmbiguousDNA() )
 # #            else:
 # #                break
-#    if header == None:
+#    if header is None:
 #        raise NoFastaException()
 #
 #    header = header.replace( "|", "_" )
