@@ -1,8 +1,5 @@
 '''
 @author: M. Bernt
-
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
 '''
 
 from sys import stdout
@@ -17,7 +14,7 @@ def sequinwriter(featurelist, acc, outfile=None, mode="w"):
     if isinstance(outfile, str):
         with open(outfile, mode) as f:
             f.write(out)
-    elif outfile == None:
+    elif outfile is None:
         stdout.write(out)
     else:
         outfile.write(out)
