@@ -1,8 +1,5 @@
 '''
 @author: M. Bernt
-
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
 '''
 
 import re
@@ -10,10 +7,15 @@ from sys import stdout
 
 from Bio import Data
 
-from ..feature import feature
-from ..gb import gb
-from ..gb.unify import unify_name_protein, unify_name_trna, unify_name_rrna, unify_name_origin
-from ..trna import codon, CodonError, L1, L2, S1, S2
+from mitos.feature import feature
+from mitos.gb import gb
+from mitos.gb.unify import (
+    unify_name_origin,
+    unify_name_protein,
+    unify_name_rrna,
+    unify_name_trna
+)
+from mitos.trna import codon, L1, L2, S1, S2
 
 
 class tblfromfile(gb):
@@ -22,7 +24,7 @@ class tblfromfile(gb):
         """
         tbl Parser that reads at least the files from MitoAnnotator
 
-        @param[in] tblfile filename string 
+        @param[in] tblfile filename string
         """
         gb.__init__(self)
 
@@ -54,7 +56,7 @@ class tblfromfile(gb):
 #                 print "size", self.size
 
             if ("CDS" in line) or ("rRNA" in line) or ("tRNA" in line) or ("D-loop" in line):
-                if position != None:
+                if position is not None:
                     self.features.append(
                         feature(name, tpe, position[0], position[1], position[2], "tbl", ""))
 #                     print "==>", self.features[-1].bedstr( self.accession )
@@ -74,7 +76,7 @@ class tblfromfile(gb):
 
             if "note" in line:
                 c = self._parse_feature_codon(" ".join(line[1:]))
-                if c != None:
+                if c is not None:
                     if name == "trnL" and c == L1:
                         name = "trnL1"
                     elif name == "trnL" and c == L2:
@@ -84,7 +86,7 @@ class tblfromfile(gb):
                     elif name == "trnS" and c == S2:
                         name = "trnS2"
 
-        if position != None:
+        if position is not None:
             self.features.append(
                 feature(name, tpe, position[0], position[1], position[2], "tbl", ""))
 #             print "==>", self.features[-1].bedstr( self.accession )
@@ -143,7 +145,7 @@ class tblfromfile(gb):
         """
         m = re.search("([U%s]{3})" %
                       Data.IUPACData.ambiguous_dna_letters, note)
-        if m != None:
+        if m is not None:
             return codon(m.group(1), "anticodon")
         else:
             return None
@@ -152,13 +154,13 @@ class tblfromfile(gb):
 def tblwriter(featurelist, acc, outfile=None, mode="w"):
     out = ">Feature %s\n" % acc
     featurelist.sort(key=lambda x: x.start)
-    for feature in featurelist:
-        out += feature.tblstr()
+    for f in featurelist:
+        out += f.tblstr()
 
     if isinstance(outfile, str):
         with open(outfile, mode) as f:
             f.write(out)
-    elif outfile == None:
+    elif outfile is None:
         stdout.write(out)
     else:
         outfile.write(out)
