@@ -1,8 +1,5 @@
 '''
 @author: M. Bernt
-
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
 '''
 
 import logging
@@ -10,9 +7,19 @@ import os
 import re
 import subprocess
 
-from .. import extprog
-from ..feature import feature, trnafeature
-from ..trna import codon, trna_nameaamap, S1, S2, L1, L2
+from mitos import extprog
+from mitos.feature import (
+    feature,
+    trnafeature,
+)
+from mitos.trna import (
+    codon,
+    L1,
+    L2,
+    S1,
+    S2,
+    trna_nameaamap,
+)
 
 
 # TODO REMOVE THIS BULLSHIT :)
@@ -31,7 +38,7 @@ class arwenscan:
     def _add_feature(self, name, tpe, start, stop, strand, translation,
                      anticodon, anticodonpos, sequence, score, dotbracket):
         """
-        add a feature .. 
+        add a feature ..
 
         """
 
@@ -51,7 +58,7 @@ class arwenscanparm(extprog.parm):
 def singleArwenScan(f, **keywords):
     """
     call singleArwenScan
-    \param file fastafile for a species, e.g. NC_010202.fas
+    @param file fastafile for a species, e.g. NC_010202.fas
 
     Detects metazoan mitochondrial tRNA genes in nucleotide sequences
 
@@ -108,14 +115,14 @@ def singleArwenScan(f, **keywords):
     pars = str(cl) + f
 
     p = subprocess.Popen("arwen %s" % (pars), shell=True, stdout=subprocess.PIPE,
-                         stderr=subprocess.PIPE, stdin=subprocess.PIPE, close_fds=True)
+                         stderr=subprocess.PIPE, stdin=subprocess.PIPE, close_fds=True, universal_newlines=True)
 
 #     if cl.get("C") == True:
 #         cfile.close()
 
     err = ""
     for i in p.stderr.readlines():
-        if i == "" or re.match("^\\d+ sequences; length of alignment \\d+\.$", i) != None:
+        if i == "" or re.match(r"^\d+ sequences; length of alignment \d+\.$", i) is not None:
             continue
         else:
             err += i + "\n"
@@ -125,7 +132,7 @@ def singleArwenScan(f, **keywords):
         logging.warning("[arwen] error with file %s: see err.log" % (f))
 
         errlog = f + "\n" + err
-        with open(os.path.dirname(file) + "/arwenScan/err.log", 'a') as errfile:
+        with open(os.path.dirname(f) + "/arwenScan/err.log", 'a') as errfile:
             errfile.write(errlog)
 
 
@@ -155,7 +162,7 @@ def parse(arwenhandler, code):
     line = arwenhandler.readline()
     # check if its normal arwenfile
     if line.startswith('>'):
-        #        acc = line.split()[0][1:]
+        # acc = line.split()[0][1:]
         # skip line "N genes found" (no need of information)
         arwenhandler.readline()
     else:
@@ -189,11 +196,11 @@ def parse(arwenhandler, code):
             # get anticodon
             try:
                 anticodon = codon(cols[5].strip("()").upper(), "anticodon")
-            except:
+            except Exception:
                 anticodon = None
 
             # get trna name
-            if code != None and anticodon != None:
+            if code is not None and anticodon is not None:
                 # get the name from the anticodon
                 name = anticodon.get_aa(code)
             else:
