@@ -1,22 +1,25 @@
 '''
 @author: M. Bernt
-
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
 '''
 
-from __future__ import print_function
-import sys
-import subprocess
-import re
-import os
 import glob
 import logging
+import os
+import re
+import subprocess
+import sys
 
-from .. import extprog
-from ..feature import trnafeature
-from ..gb import gbfromfile
-from . import trna_nameaamap, L1, L2, S1, S2, codon
+from mitos import extprog
+from mitos.feature import trnafeature
+from mitos.gb import gbfromfile
+from mitos.trna import (
+    codon,
+    L1,
+    L2,
+    S1,
+    S2,
+    trna_nameaamap,
+)
 
 
 class trnascanparm(extprog.parm):
@@ -42,7 +45,7 @@ def getGencodeFromTranl_tableNumber(tableno):
     # print pars
     p = subprocess.Popen("which tRNAscan-SE", shell=True,
                          stdout=subprocess.PIPE, stderr=subprocess.PIPE,
-                         close_fds=True)
+                         close_fds=True, universal_newlines=True)
 
     err = ""
     for i in p.stderr.readlines():
@@ -64,9 +67,9 @@ def getGencodeFromTranl_tableNumber(tableno):
 def singletrnascan(f, **keywords):
     """
     call trnascan
-    \param f fastafile for a species, e.g. NC_010202.fas
+    param f fastafile for a species, e.g. NC_010202.fas
 
-    -O  
+    -O
         search for organellar (mitochondrial/chloroplast) tRNAs
 
         This parameter bypasses the fast first-pass scanners that are
@@ -91,7 +94,7 @@ def singletrnascan(f, **keywords):
         Seq:   GCCTCGATAGCTCAGTTGGGAGAGCGTACGACTGAAGATCGTAAGGtCACCAGTTCGATCCTGGTTCGGGGCA
         Str:   >>>>>>>..>>>>........<<<<.>>>>>.......<<<<<.....>>>>>.......<<<<<<<<<<<<.
 
-    -q  
+    -q
         quiet mode (credits & run  option  selections  suppressed)
 
         This  option suppresses the program credits and run option selec-
@@ -170,16 +173,16 @@ def singletrnascan(f, **keywords):
     # print pars
     p = subprocess.Popen("tRNAscan-SE %s" % (pars), shell=True,
                          stdout=subprocess.PIPE, stderr=subprocess.PIPE,
-                         stdin=subprocess.PIPE, close_fds=True)
-    if cfile != None:
+                         stdin=subprocess.PIPE, close_fds=True, universal_newlines=True)
+    if cfile is not None:
         p.stdin.write(cfile.read())
 
-    if cl.get("C") == True:
+    if cl.get("C") is True:
         cfile.close()
 
     err = ""
     for i in p.stderr.readlines():
-        if i == "" or re.match("^\\d+ sequences; length of alignment \\d+\.$", i) != None:
+        if i == "" or re.match(r"^\d+ sequences; length of alignment \d+\.$", i) is not None:
             continue
         else:
             err += i + "\n"
@@ -209,11 +212,11 @@ def trnascan(d):
         outfile = d + 'tRNAScan/' + os.path.basename(f) + '.ss'
         try:
             gencode = getGencodeFromTranl_tableNumber(str(gbdata.transl_table))
-        except:
+        except Exception:
             logging.debug("Could not determine genetic code for %s" % (f))
             gencode = None
 
-        if gencode != None:
+        if gencode is not None:
             singletrnascan(
                 f, Q=True, O=True, b=True, X=5, q=True, f=outfile, g=gencode)
         else:
@@ -227,7 +230,7 @@ def parse(fh, code):
     - skip tRNAs reported with introns
     - skip tRNAs reported with unknown anticodon
 
-    @param[in] fh a file handle 
+    @param[in] fh a file handle
     @param genetic code (table number), if not given the tRNAs given in the file are just taken
     @return list of tRNA features
     """
@@ -247,12 +250,12 @@ def parse(fh, code):
     anticodonpos = None
     anticodon = None
 
-    for l in fh.readlines():
-        l = l.lstrip().rstrip().split()
+    for line in fh.readlines():
+        line = line.lstrip().rstrip().split()
 
         # empty line marks start of a new feature
-        if not l:
-            if skip == False:
+        if not line:
+            if skip is False:
                 trnas.append(trnafeature(name=name, type="tRNA",
                                          start=start, stop=stop, strand=strand,
                                          method="tRNAscan", score=score, sequence=seq,
@@ -265,13 +268,16 @@ def parse(fh, code):
             # datensatz fertig, schreiben
 
         # if l[0].startswith('NC_'): #USE THIS LINE
-        if l[0].startswith('NC_') or l[0].startswith('As_mt_') or l[0].startswith('Bc_mt') or l[0].startswith('Ec1-6') or l[0].startswith('Gg_cons') or l[0].startswith('Hf_mt') or l[0].startswith('On_mt'):
+        if (line[0].startswith('NC_') or line[0].startswith('As_mt_')
+                or line[0].startswith('Bc_mt') or line[0].startswith('Ec1-6')
+                or line[0].startswith('Gg_cons') or line[0].startswith('Hf_mt')
+                or line[0].startswith('On_mt')):
             #            number = l[0].split( '.' )[-1][4:]
 
             # trnascan: positions are counted from 1 the first and the last
             # position belongs to the trna
-            start = int(l[1].split('-')[0][1:]) - 1
-            stop = int(l[1].split('-')[1][:-1]) - 1
+            start = int(line[1].split('-')[0][1:]) - 1
+            stop = int(line[1].split('-')[1][:-1]) - 1
 
             # is start < stop then the sequence if on the reverse complement
             if start > stop:
@@ -280,22 +286,22 @@ def parse(fh, code):
             else:
                 strand = 1
 
-        elif l[0].startswith('Type:'):
-            if l[3] == "???":
+        elif line[0].startswith('Type:'):
+            if line[3] == "???":
                 skip = True
 
-            anticodon = codon(l[3], "anticodon")
-            anticodonpos = int(l[5].split('-')[0])
+            anticodon = codon(line[3], "anticodon")
+            anticodonpos = int(line[5].split('-')[0])
 
-            if code != None:
+            if code is not None:
                 name = anticodon.get_aa(code)
             else:
-                if l[1] in trna_nameaamap:
-                    name = trna_nameaamap[l[1]]
+                if line[1] in trna_nameaamap:
+                    name = trna_nameaamap[line[1]]
                 else:
-                    name = l[1]
+                    name = line[1]
 
-            score = float(l[8])
+            score = float(line[8])
 
             if name == "S":
                 if anticodon == S1:
@@ -304,7 +310,7 @@ def parse(fh, code):
                     name = "S2"
                 else:
                     name = "S"
-                    logging.warning("warning non standard Ser %s" % l[3])
+                    logging.warning("warning non standard Ser %s" % line[3])
 
             if name == "L":
                 if anticodon == L1:
@@ -313,35 +319,35 @@ def parse(fh, code):
                     name = "L2"
                 else:
                     name = "L"
-                    logging.warning("warning non standard Leu %s" % l[3])
+                    logging.warning("warning non standard Leu %s" % line[3])
 
             continue
 
-        elif l[0].startswith('Possible'):
+        elif line[0].startswith('Possible'):
             skip = True
-            intronstart = int(l[2].split('-')[0][1:]) - 1
-            intronstop = int(l[2].split('-')[1][:-1]) - 1
+            intronstart = int(line[2].split('-')[0][1:]) - 1
+            intronstop = int(line[2].split('-')[1][:-1]) - 1
             if intronstart > intronstop:
                 intronstart, intronstop = intronstop, intronstart
             continue
 
-        elif l[0].startswith('*'):
+        elif line[0].startswith('*'):
             continue
 
-        elif l[0].startswith('Seq'):
-            seq = l[1]
+        elif line[0].startswith('Seq'):
+            seq = line[1]
             continue
 
-        elif l[0].startswith('Str'):
+        elif line[0].startswith('Str'):
             # read struckture
-            dotbracket = re.sub('>', '(', re.sub('<', ')', l[1]))
+            dotbracket = re.sub('>', '(', re.sub('<', ')', line[1]))
             # printing anticodon position in struckture
 #            dotbracket = dotbracket[:anticodonpos-1]+"AAA"+dotbracket[anticodonpos+2:]
             continue
 
         else:
             logging.error(
-                "unexpected line in tRNAscan output {line}".format(line=l))
+                "unexpected line in tRNAscan output {line}".format(line=line))
             sys.exit()
 
 #    trnas.sort( key = lambda x : x.start )
