@@ -1,17 +1,18 @@
-from __future__ import print_function
+
 import argparse
-import cPickle
 import itertools
 import logging
-import os.path
-import random
-import sys
-import re
 import multiprocessing
+import os.path
+import pickle
+import random
+import re
+import sys
+
 import numpy
 
-import rna.forester
-import mitofile
+from mitos import mitofile
+from mitos import rna
 
 
 def apply_statistics(allocomp, allocompdist, isocomp, isocompdist):
@@ -81,7 +82,7 @@ def apply_statistics(allocomp, allocompdist, isocomp, isocompdist):
                 # that are <= the value; thus large ranks are of interest
                 # (which is as in the z-score)
                 rank = len(
-                    [x for x in allocompdist[name][name2] if(x < allocomp[acc][name][i]["sim"])])
+                    [x for x in allocompdist[name][name2] if x < allocomp[acc][name][i]["sim"]])
                 # norm
 
                 allocomp[acc][name][i]["rank"] = float(
@@ -90,8 +91,8 @@ def apply_statistics(allocomp, allocompdist, isocomp, isocompdist):
 
 def compare(p):
     """
-    execute a comparison function for a pair of 
-    list of sequences and list of structures 
+    execute a comparison function for a pair of
+    list of sequences and list of structures
     """
     # print p[0], p[1], rna.forester.RNAforester(sequences = p[0],structures =
     # p[1], r = True )
@@ -166,7 +167,7 @@ def get_alloacceptorhist(data, fname):
             f.write(str(feat.name) + "\n")
             try:
                 hist[str(feat.name)] += 1
-            except:
+            except KeyError:
                 hist[str(feat.name)] = 1
 
     f.close()
@@ -178,15 +179,15 @@ def get_alloacceptorhist(data, fname):
 def get_allocomparisons(data, threads):
     """
     get the comparisions of the tRNAs in the same species
-    (the name is due that originally only those with different 
+    (the name is due that originally only those with different
     alloacceptor have been generated)
 
-    @param data the data 
+    @param data the data
     @param threads number of threads to use
     """
 
     p = multiprocessing.Pool(threads)
-    dmatrix = p.map(compareaa, data.values())
+    dmatrix = p.map(compareaa, list(data.values()))
     p.close()
     p.join()
 
@@ -197,13 +198,13 @@ def get_allocomparisons(data, threads):
         # print(acc)
         sys.stderr.write("allo %s %d/%d\r" % (acc, x + 1, len(data)))
 
-        if not acc in allocomp:
+        if acc not in allocomp:
             allocomp[acc] = {}
 
 #        dmatrix = compareaa( data[acc] )
         for i in range(len(data[acc])):
             f1 = data[acc][i]
-            if not f1.name in allocomp[acc]:
+            if f1.name not in allocomp[acc]:
                 allocomp[acc][f1.name] = []
             # compare to different alloacceptor in the same species
             for j in range(len(data[acc])):
@@ -239,11 +240,11 @@ def get_allocompdist(allocomp, fname):  # i'm here now
     allocompdist = {}
     for acc in allocomp:
         for name in allocomp[acc]:
-            if not name in allocompdist:
+            if name not in allocompdist:
                 allocompdist[name] = {}
 
             for i in range(len(allocomp[acc][name])):
-                if not allocomp[acc][name][i]['t2'].name in allocompdist[name]:
+                if allocomp[acc][name][i]['t2'].name not in allocompdist[name]:
                     allocompdist[name][allocomp[acc][name][i]['t2'].name] = []
                 allocompdist[name][allocomp[acc][name][i]['t2'].name].append(
                     allocomp[acc][name][i]['sim'])
@@ -265,12 +266,11 @@ def get_isocomp(data, tax, threads, mult):
 
     """
     isocomp = {}
-
-    l = 1
+    ln = 1
     for acc in data:
 
-        sys.stderr.write("iso %s %d/%d\r" % (acc, l, len(data)))
-        if not acc in isocomp:
+        sys.stderr.write("iso %s %d/%d\r" % (acc, ln, len(data)))
+        if acc not in isocomp:
             isocomp[acc] = {}
 
         # get trnas with the same anticodon
@@ -280,7 +280,7 @@ def get_isocomp(data, tax, threads, mult):
         st = sorted_taxonomy(acc, tax)
         for ac in anticodons:
 
-            if not ac in isocomp[acc]:
+            if ac not in isocomp[acc]:
                 isocomp[acc][ac] = []
 
             cand = {}
@@ -327,7 +327,7 @@ def get_isocomp(data, tax, threads, mult):
                     for c2 in cand[accession2]:
                         isocomp[acc][ac].append(
                             {"t1": c1, "t2": c2, "sim": 0, "wrt": accession2})
-        l += 1
+        ln += 1
 
     # compile comparisons to execute
     comparisons = []
@@ -361,7 +361,7 @@ def get_isocomp(data, tax, threads, mult):
             isocomp[acc][ac] = []
 
             for t in t1s:
-                best = [z for z in tmp if(z['t1'] == t)]
+                best = [z for z in tmp if z['t1'] == t]
                 best.sort(key=lambda k: k['sim'])
                 isocomp[acc][ac].append(best[0])
 
@@ -373,7 +373,7 @@ def get_isocompdist(isocomp, fname):
     f = open(fname, "w")
     for acc in isocomp:
         for ac in isocomp[acc]:
-            if not ac in isocompdist:
+            if ac not in isocompdist:
                 isocompdist[ac] = []
 
             for i in range(len(isocomp[acc][ac])):
@@ -404,7 +404,7 @@ def get_isoacceptorhist(data, fname):
             f.write(str(feat.anticodon) + "\n")
             try:
                 hist[str(feat.anticodon)] += 1
-            except:
+            except KeyError:
                 hist[str(feat.anticodon)] = 1
     f.close()
 
@@ -413,13 +413,13 @@ def get_isoacceptorhist(data, fname):
 
 def get_results(data, allocomp, allocompdist, isocomp, isocompdist, stat, fname):
     """
-    @param data 
+    @param data
     @param allocomp
     @param allocompdist
-    @param isocomp 
+    @param isocomp
     @param isocompdist
     @param stat statistics to use (z/rank/sim)
-    fname 
+    fname
     """
     # print "Allocomp", allocomp, "End-Allocomp "+stat+"\n \n \n"
     # print "Allocompdist", allocompdist, "End-Allocomp dist \n \n \n"
@@ -430,9 +430,9 @@ def get_results(data, allocomp, allocompdist, isocomp, isocompdist, stat, fname)
     f = open(fname, "w")
 
     stop = False
-    l = 0
+    ln = 1
     for acc in data:
-        sys.stderr.write("%s %d/%d\r" % (acc, l + 1, len(data)))
+        sys.stderr.write("%s %d/%d\r" % (acc, ln + 1, len(data)))
 
         # if acc != "NC_008140":
         for i in range(len(data[acc])):
@@ -461,17 +461,17 @@ def get_results(data, allocomp, allocompdist, isocomp, isocompdist, stat, fname)
             for acmp in allocomp[acc][data[acc][i].name]:
                 # fraction of the allo-comparisons that are more similar than
                 # this pair
-                if maxcmpap == None or acmp[stat] > maxcmpap[stat]:
+                if maxcmpap is None or acmp[stat] > maxcmpap[stat]:
                     maxcmpap = acmp
 
             # determine min similarity of the tRNA with another with the same
             # isoacc
             comparision = [x for x in isocomp[acc][str(data[acc][i].anticodon)]
-                           if(x['t1'] == data[acc][i])]
+                           if x['t1'] == data[acc][i]]
 
             mincmpip = None
             for c in comparision:
-                if mincmpip == None or c[stat] < mincmpip[stat]:
+                if mincmpip is None or c[stat] < mincmpip[stat]:
                     mincmpip = c
 
             try:
@@ -481,7 +481,7 @@ def get_results(data, allocomp, allocompdist, isocomp, isocompdist, stat, fname)
                                                                           maxcmpap['t1'].name, maxcmpap['t2'].name, maxcmpap[
                                                                               'sim'], maxcmpap['rank'], maxcmpap['z'],
                                                                           mincmpip['wrt'], str(mincmpip['t2'].anticodon), mincmpip['sim'], mincmpip['rank'], mincmpip['z']))
-            except:
+            except Exception:
                 sys.stderr.write("%s %s %s %s\n" % (
                     acc, data[acc][i].name, data[acc][i].anticodon, repr(data[acc][i])))
                 print(mincmpip)
@@ -496,12 +496,11 @@ def get_results(data, allocomp, allocompdist, isocomp, isocompdist, stat, fname)
                 stop = True
                 break
             # else:
-             #   continue
+            #    continue
 
-        if stop == True:
+        if stop is True:
             break
-        l += 1
-
+        ln += 1
 
 #            .append( { "t1": c1, "t2":c2, "sim":compare( c1, c2 ), "wrt": accession2 } )
     f.close()
@@ -534,7 +533,7 @@ def load_data(dirs):
     # random bases(ACGTU)
     for dr in dirs:
         # if not os.listdir(dr) == []:
-            # continue
+        #     continue
         if not os.path.isdir(dr):
             sys.stderr.write("skipping non dir %s\n" % dr)
             continue
@@ -547,20 +546,20 @@ def load_data(dirs):
 
         try:
             f = open(dr + "/result.pkl")
-            features = cPickle.load(f)
+            features = pickle.load(f)
             f.close()
         except IOError:
             sys.stderr.write("skipping (no features) %s\n" % dr)
             continue
 
         tmp = [x for x in features if (
-            x.type == "tRNA" and x.anticodon == None)]
+            x.type == "tRNA" and x.anticodon is None)]
         for t in tmp:
             logging.warning("remove degenerated tRNA: %s %s" %
                             (gb.accession, t.name))
 
         data[gb.accession] = [
-            x for x in features if (x.type == "tRNA" and x.anticodon != None)]
+            x for x in features if (x.type == "tRNA" and x.anticodon is not None)]
 
         for i in range(len(data[gb.accession])):
             while 1:
@@ -594,29 +593,29 @@ def load_taxonomy(taxfname):
 def sorted_taxonomy(acc, tax):
     """
     given an accession a and the taxonomy lists for a set of accessions S
-    including the accession a itself return a list of the accessions S 
-    sorted by their distance to a. The distance is the distance in the tree. 
-    Let a and b two accessions and T_a and T_b their accesion lists, and 
+    including the accession a itself return a list of the accessions S
+    sorted by their distance to a. The distance is the distance in the tree.
+    Let a and b two accessions and T_a and T_b their accesion lists, and
     C be the common prefix of T_a and T_b. Then the distance is computed as
-    (|T_a|-|C|)+(|T_b|-|C|).  
+    (|T_a|-|C|)+(|T_b|-|C|).
 
     @param acc accession
     @param tax taxonomy lists for all accessions given as dict
-    @return sorted list of accessions  
+    @return sorted list of accessions
     """
     st = {}
     for t in tax:
-        l = len_common_prefix(tax[acc], tax[t])
-        d = (len(tax[acc]) - l) + (len(tax[t]) - l)
+        lcp = len_common_prefix(tax[acc], tax[t])
+        d = (len(tax[acc]) - lcp) + (len(tax[t]) - lcp)
 
-        if not d in st:
+        if d not in st:
             st[d] = []
 
         st[d].append(t)
 
     return st
 
-#    return dist
+
 if __name__ == '__main__':
     usage = "usage: %prog dirs"
     parser = argparse.ArgumentParser(description=usage)
@@ -652,12 +651,12 @@ if __name__ == '__main__':
     sys.stderr.write("alloacceptor comparisons\n")
     if os.path.exists("allocomp.pkl"):
         f = open("allocomp.pkl")
-        allocomp = cPickle.load(f)
+        allocomp = pickle.load(f)
         f.close()
     else:
         allocomp = get_allocomparisons(data, args.threads)
         f = open("allocomp.pkl", "w")
-        cPickle.dump(allocomp, f)
+        pickle.dump(allocomp, f)
         f.close()
 
     # pairs of trnas with the same isoacceptor from the same or related species
@@ -665,12 +664,12 @@ if __name__ == '__main__':
     sys.stderr.write("isoacceptor comparisons\n")
     if os.path.exists("isocomp.pkl"):
         f = open("isocomp.pkl")
-        isocomp = cPickle.load(f)
+        isocomp = pickle.load(f)
         f.close()
     else:
         isocomp = get_isocomp(data, tax, args.threads, False)
         f = open("isocomp.pkl", "w")
-        cPickle.dump(isocomp, f)
+        pickle.dump(isocomp, f)
         f.close()
 
     # print isocomp, "test"
