@@ -1,48 +1,39 @@
 '''
 @author: M. Bernt
-
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
 '''
 
-from Bio import GenBank
-from Bio import Data
-
-import datetime
 import glob
 import json
 import logging
 import math
 import os
-from os.path import basename, exists, splitext
 import re
-try:  # python2
-    from StringIO import StringIO
-except ImportError:  # python3
-    from io import StringIO
 import subprocess
 import sys
-import time
 import traceback
+from io import StringIO
 
-from ..gb import gbfromfile
-from .. import mitfi
-from .. import sequence
-from ..trna import arwenscan, trnascan
+from Bio import (
+    Data,
+    GenBank
+)
+
+from mitos import sequence
+from mitos.trna import trnascan
 
 
 def _add_one_codonstats(cod_stat, tpe, code, name, codon):
     try:
         cod_stat[tpe][code][name][str(codon)] += 1
-    except:
+    except KeyError:
         cod_stat[tpe][code][name][str(codon)] = 1
 
 
 def _init_codonstats(cod_stat, code, name):
     for t in ["start", "stop", "inner"]:
-        if not code in cod_stat[t]:
+        if code not in cod_stat[t]:
             cod_stat[t][code] = {}
-        if not name in cod_stat[t][code]:
+        if name not in cod_stat[t][code]:
             cod_stat[t][code][name] = {}
 
             if str(code).endswith("*"):
@@ -59,31 +50,31 @@ def _init_codonstats(cod_stat, code, name):
 
 def _append_len_list(len_lists, code, name, ln):
 
-    if not code in len_lists:
+    if code not in len_lists:
         len_lists[code] = {}
-    if not name in len_lists[code]:
+    if name not in len_lists[code]:
         len_lists[code][name] = []
     len_lists[code][name].append(ln)
 
 
 def prepareFiles(data, outdir, codss, codin, delinner):
     """
-    - create sub directories 'featureNuc' and 'featureProt' (old data is 
+    - create sub directories 'featureNuc' and 'featureProt' (old data is
       removed if existent)
-    - for each genbank file in files: 
-      * write nucleotide sequences of the features annotated in the genbank 
-        file to the corresponding file in 'featureNuc' 
-      * write amino acid sequences of the features annotated in the genbank 
-        file file to the corresponding file in 'featureProt' (take the given 
-        amino acid sequence, NOT the translation of the annotated range) 
-    - create BLAST data bases of all created fasta 
+    - for each genbank file in files:
+      * write nucleotide sequences of the features annotated in the genbank
+        file to the corresponding file in 'featureNuc'
+      * write amino acid sequences of the features annotated in the genbank
+        file file to the corresponding file in 'featureProt' (take the given
+        amino acid sequence, NOT the translation of the annotated range)
+    - create BLAST data bases of all created fasta
     - create the data file for non-canonical start codons and gene length statistics
     @param data list of genbank data
-    @param outdir the directory where the BLAST data bases and 
+    @param outdir the directory where the BLAST data bases and
         the non-canonical start codon file should be written
-    @param codss minimum fraction of appearances of a codon (per gene and code) 
+    @param codss minimum fraction of appearances of a codon (per gene and code)
         as start/stop to be accepted as start/stop
-    @param codin maximum fraction of appearances of a codon (per gene and code) 
+    @param codin maximum fraction of appearances of a codon (per gene and code)
         as inner codon to be accepted as stop
     @param delinner remove statistics on inner codons from data before dumping
 
@@ -159,11 +150,10 @@ def prepareFiles(data, outdir, codss, codin, delinner):
             if feature.type in ["tRNA", "rRNA"]:
                 continue
 
-            if not (feature.part == None or feature.part == 0):
+            if not (feature.part is None or feature.part == 0):
                 continue
 
-            parts = [x for x in features if x.name ==
-                     feature.name and x.copy == feature.copy]
+            parts = [x for x in features if x.name == feature.name and x.copy == feature.copy]
             parts.sort(key=lambda x: x.part)
 
             fname = feature.name
@@ -180,7 +170,7 @@ def prepareFiles(data, outdir, codss, codin, delinner):
             if len(seq) < 6:
                 continue
 
-            if not fname in fas2len:
+            if fname not in fas2len:
                 fas2len[fname] = {}
 
             output = ">%s:%s-%d-%d-%d %s\n%s\n" % (
@@ -190,9 +180,9 @@ def prepareFiles(data, outdir, codss, codin, delinner):
             # 60%)
             nfreq = seq.nucleotide_frequency()
             stdf = 0
-            for l in Data.IUPACData.unambiguous_dna_letters:
-                if l in nfreq:
-                    stdf += nfreq[l]
+            for letter in Data.IUPACData.unambiguous_dna_letters:
+                if letter in nfreq:
+                    stdf += nfreq[letter]
 
             if stdf >= .6:
                 fh = open(feature_nuc_file, "a")
@@ -203,7 +193,7 @@ def prepareFiles(data, outdir, codss, codin, delinner):
                     gene=fname, acc=gbdata.accession, std=stdf))
 
             # prepare fasta files with proteins
-            if feature.translation != None:
+            if feature.translation is not None:
                 feature_prot_file = feature_prot_path + fname + ".fas"
                 prot_output = ">%s:%s-%d-%d-%d %s\n%s\n" % (
                     acc, feature.getname(), fstrand, fstart, fstop, name, str(feature.translation))
@@ -257,9 +247,9 @@ def prepareFiles(data, outdir, codss, codin, delinner):
                 # inner
                 for j in range(3, stopf, 3):
                     codon = str(seq.subseq(j, j + 2, 1))
-                    if not (codon[0] in Data.IUPACData.unambiguous_dna_letters and
-                            codon[1] in Data.IUPACData.unambiguous_dna_letters and
-                            codon[2] in Data.IUPACData.unambiguous_dna_letters):
+                    if not (codon[0] in Data.IUPACData.unambiguous_dna_letters
+                            and codon[1] in Data.IUPACData.unambiguous_dna_letters
+                            and codon[2] in Data.IUPACData.unambiguous_dna_letters):
                         continue
 
 #                     sys.stdout.write( "%s %s\n" % ( gbdata.accession, codon ) )
@@ -277,7 +267,7 @@ def prepareFiles(data, outdir, codss, codin, delinner):
         cmd = ["makeblastdb", "-dbtype", "nucl", "-in", fname]
 
         out, err = subprocess.Popen(cmd, stdout=subprocess.PIPE,
-                                    stderr=subprocess.PIPE).communicate()
+                                    stderr=subprocess.PIPE, universal_newlines=True).communicate()
         if len(err) > 0:
             logging.error("makeblastdb exception\n%s\n%s" %
                           (" ".join(cmd), err))
@@ -289,7 +279,7 @@ def prepareFiles(data, outdir, codss, codin, delinner):
     for fname in glob.glob('%s/*.fas' % (feature_prot_path)):
         cmd = ["makeblastdb", "-dbtype", "prot", "-in", fname]
         out, err = subprocess.Popen(cmd, stdout=subprocess.PIPE,
-                                    stderr=subprocess.PIPE).communicate()
+                                    stderr=subprocess.PIPE, universal_newlines=True).communicate()
         if len(err) > 0:
             logging.error("makeblastdb exception\n%s\n%s" %
                           (" ".join(cmd), err))
@@ -318,7 +308,7 @@ def prepareFiles(data, outdir, codss, codin, delinner):
                     if t == "stop":
                         try:  # get usage of the codon inside the gene
                             uai = cod_stat["inner"][code][name][codon]
-                        except:
+                        except KeyError:
                             uai = 0
 
                         if cod_stat[t][code][name][codon] < codss or uai >= codin:
@@ -367,14 +357,14 @@ def prepareFiles(data, outdir, codss, codin, delinner):
         cod_stat["stop"]["14*"] = cod_stat["stop"]["9*"]
         cod_stat["inner"]["14*"] = cod_stat["inner"]["9*"]
 
-        if not "14" in cod_stat["start"]:
+        if "14" not in cod_stat["start"]:
             cod_stat["start"]["14"] = {}
-        if not "14" in cod_stat["stop"]:
+        if "14" not in cod_stat["stop"]:
             cod_stat["stop"]["14"] = {}
         for name in cod_stat["start"]["9"]:
-            if not name in cod_stat["start"]["14"]:
+            if name not in cod_stat["start"]["14"]:
                 cod_stat["start"]["14"][name] = {}
-            if not name in cod_stat["stop"]["14"]:
+            if name not in cod_stat["stop"]["14"]:
                 cod_stat["stop"]["14"][name] = {}
 
             for c in Data.CodonTable.unambiguous_dna_by_id[int(code)].start_codons:
@@ -398,10 +388,10 @@ def refseqsplit(fname, dname, prefix=None, atax=None, ftax=None, maxentries=Fals
     @param fname input multi genbank file
     @param dname directory for writing the output
     @param prefix only accession numbers with this prefix (e.g. NC) are allowed
-          (default: None, i.e. allow all prefixes)  
-    @param atax a list of taxonomic entities, only species belonging to one of 
-           the taxonomix groups are accepted (default: None, i.e. allow everything) 
-    @param ftax a list of taxonomic entities, reject species belonging to one of 
+          (default: None, i.e. allow all prefixes)
+    @param atax a list of taxonomic entities, only species belonging to one of
+           the taxonomix groups are accepted (default: None, i.e. allow everything)
+    @param ftax a list of taxonomic entities, reject species belonging to one of
            the taxonomix groups (default: None, i.e. reject nothing)
     @param maxentries  maximum number of genbank files to write
     """
@@ -410,7 +400,7 @@ def refseqsplit(fname, dname, prefix=None, atax=None, ftax=None, maxentries=Fals
 
     try:
         fhandle = open(fname, 'r')
-    except:
+    except Exception:
         logging.error("error: could not open %s for reading\n" % (fname))
         sys.exit(1)
 
@@ -422,7 +412,7 @@ def refseqsplit(fname, dname, prefix=None, atax=None, ftax=None, maxentries=Fals
             break
 
         cgb += nxt
-        if re.match("^//$", nxt) != None:
+        if re.match("^//$", nxt) is not None:
             gb_iterator = GenBank.Iterator(
                 StringIO(cgb), GenBank.FeatureParser())
 
@@ -467,14 +457,14 @@ def refseqsplit(fname, dname, prefix=None, atax=None, ftax=None, maxentries=Fals
 #                print filter( lambda x:x in tax, ftax )
 
             skip = False
-            if prefix != None and not cur_record.name.startswith(prefix):
+            if prefix is not None and not cur_record.name.startswith(prefix):
                 logging.debug("%s prefix skip" % cur_record.name)
                 skip = True
-            if atax != None and len([x for x in atax if x in tax]) == 0:
+            if atax is not None and len([x for x in atax if x in tax]) == 0:
                 logging.debug("%s allowed tax skip (%s)" %
                               (cur_record.name, str(tax)))
                 skip = True
-            if ftax != None and len([x for x in ftax if x in tax]) > 0:
+            if ftax is not None and len([x for x in ftax if x in tax]) > 0:
                 logging.debug("%s forbidden tax skip (%s)" %
                               (cur_record.name, str(tax)))
                 skip = True
@@ -484,7 +474,7 @@ def refseqsplit(fname, dname, prefix=None, atax=None, ftax=None, maxentries=Fals
                 ofile = dname + "/" + cur_record.name + ".gb"
                 try:
                     ohandle = open(ofile, "w")
-                except:
+                except Exception:
                     logging.error("error: could not write to %s\n" % ofile)
                     sys.exit()
 
@@ -504,10 +494,10 @@ def refseqsplit(fname, dname, prefix=None, atax=None, ftax=None, maxentries=Fals
 
 def singleblastx(seqfile, code, outputdir, refdir):
     """
-    run blastall blastx 
+    run blastall blastx
     store results in OUTPUTDIR/blast/prot/(absname of seqfile)
     @param seqfile a (single) fasta sequenz file
-    @param code genetic code 
+    @param code genetic code
     @param outputdir directory for writing the results
     @param[in] refseqver version of refseq to use
     @param[in] refdir directory containing reference data
@@ -523,7 +513,7 @@ def singleblastx(seqfile, code, outputdir, refdir):
     prot_path = "{refdir}/featureProt/".format(refdir=refdir)
     prot_files = glob.glob(prot_path + "*.fas")
 
-    acc = splitext(basename(seqfile))[0]
+    # acc = splitext(basename(seqfile))[0]
 
     # create directories
     if not os.path.exists('%s/blast' % (outputdir)):
@@ -556,9 +546,9 @@ def singleblastx(seqfile, code, outputdir, refdir):
 
         cmd = ["blastx", "-query", seqfile] + param
         logging.debug(" ".join(cmd))
-        out, err = subprocess.Popen(cmd, stdout=subprocess.PIPE,
-                                    stderr=subprocess.PIPE).communicate()
-        if len(err) > 0:
+        proc = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True)
+        out, err = proc.communicate()
+        if proc.returncode or len(err) > 0:
             logging.error("blastx exception\n%s" % err)
             raise Exception(err)
 #             # -F "m S" filter SEG (aa low complexity filter) allow extension through low complexity regions
@@ -585,7 +575,7 @@ def singleblastn(seqfile, outputdir, refdir):
 # maxint = 2147483647  # realy big number to make sure blast reports all
 # results
 
-    acc = splitext(basename(seqfile))[0]
+    # acc = splitext(basename(seqfile))[0]
 
     # Creat Dirs
     if not os.path.exists('%s/blast' % (outputdir)):
@@ -621,9 +611,9 @@ def singleblastn(seqfile, outputdir, refdir):
 
         cmd = ["blastn", "-query", seqfile] + param
         logging.debug(" ".join(cmd))
-        out, err = subprocess.Popen(cmd, stdout=subprocess.PIPE,
-                                    stderr=subprocess.PIPE).communicate()
-        if len(err) > 0:
+        proc = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True)
+        out, err = proc.communicate()
+        if proc.returncode or len(err) > 0:
             logging.error("blastn exception\n%s" % err)
             raise Exception(err)
 
@@ -670,12 +660,12 @@ def singletrnascan(sequenzfile, code, outdir):
     # Start scan
     try:
         gencode = trnascan.getGencodeFromTranl_tableNumber(str(code))
-    except:
+    except Exception:
         logging.debug("Could not determine genetic code for %s" %
                       (sequenzfile))
         gencode = None
 
-    if gencode != None:
+    if gencode is not None:
         trnascan.singletrnascan(
             sequenzfile, Q=True, O=True, b=True, X=5, q=True, f=outfile, g=gencode)
     else:
