@@ -3,17 +3,14 @@
 '''
 @author: M. Bernt
 
-This is a confidential release. Do not redistribute without 
-permission of the author (bernt@informatik.uni-leipzig.de).
-
-program to split a given refseq file (containing the concatenation of all 
+program to split a given refseq file (containing the concatenation of all
 genbank files) into its components
 additionally a prefix and taxonomy filter can be applied
 '''
 
 
-import logging
 import argparse
+import logging
 from sys import exit
 
 from mitos import update
@@ -40,10 +37,10 @@ args = parser.parse_args()
 
 logging.basicConfig(level=max(logging.WARNING - (args.verbose * 10), 10))
 
-if args.file == None:
+if args.file is None:
     logging.error("no file given")
     exit(1)
-if args.dir == None:
+if args.dir is None:
     logging.error("error: no dir given")
     exit(1)
 
