@@ -2,15 +2,13 @@
 
 '''
 @author: M. Bernt
-
-This is a confidential release. Do not redistribute without
-permission of the author (bernt@informatik.uni-leipzig.de).
 '''
 
 import io
 import json
 import logging
 import os
+import re
 import subprocess
 import sys
 
@@ -22,8 +20,8 @@ from mitos import (
     __version__,
     bedfile,
     blast,
-    gfffile,
     feature,
+    gfffile,
     mitfi,
     mito,
     protfeat,
@@ -31,9 +29,9 @@ from mitos import (
     trna
 )
 from mitos.mergefeature import (
-    featureappend,
+    _copy_part,
     checklocalfeature,
-    _copy_part
+    featureappend
 )
 from mitos.mitofile import mitowriter
 from mitos.rna.vienna import RNAplot
@@ -57,7 +55,7 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
     @param[in] code the genetic code X / X* (is given as string)
     @param[in] ncbicode true: use the NCBI standard, false use learned code
     @param[in] best annotate only the best copy of each feature
-    @param[in] order list of feature types to be added in the 1st round accepted 
+    @param[in] order list of feature types to be added in the 1st round accepted
         content is gene, tRNA, rRNA, OL, OH
     @param[in] alarab use the method of Al Arab et al 2016 for protein prediction
     @param[in] outdir directory for the output (if None MITOS uses the
@@ -73,7 +71,7 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
     @param[in] refseqver version of RefSeq to use
     @param[in] ncev evalue to be used in inferal fast mode
     @param[in] circular treat sequence as circular
-    @param[in] circrot circular rotation \in [0:179] for the treatment of mitogenomes rotation of circrot and circrot+180 are tested
+    @param[in] circrot circular rotation in [0:179] for the treatment of mitogenomes rotation of circrot and circrot+180 are tested
     @param[in] trnaovl max overlap allowed between trna
     @param[in] rrnaovl max overlap allowed between rrna
     @param[in] oldstst use the old start stop prediction method of MITOS1
@@ -84,10 +82,10 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
 
 #     import inspect
 #     frame = inspect.currentframe()
-#     args, _, _, values = inspect.getargvalues( frame )
-#     logging.debug( 'function name "%s"' % inspect.getframeinfo( frame )[2] )
+#     args, _, _, values = inspect.getargvalues(frame)
+#     logging.debug('function name "%s"' % inspect.getframeinfo(frame)[2])
 #     for i in args:
-#         logging.debug( "    %s = %s" % ( i, values[i] ) )
+#         logging.debug("    %s = %s" % (i, values[i]))
     prot = "gene" in order
     trna = "tRNA" in order
     rrna = "rRNA" in order
@@ -143,7 +141,7 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
         fas2len = None
 
     # the path for storing the output
-    if outdir == None:
+    if outdir is None:
         path = os.path.dirname(fastafile) + "/"
     else:
         path = outdir + "/"
@@ -190,12 +188,12 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
 #     # for analyzing a circular sequence correctly sequence is doubled and
 #     # stores under .lin in the output directory
 #     if circular:
-#         sr = SeqRecord( seq = fasta[0]["sequence"] + fasta[0]["sequence"][:int( circextend * length )], \
-#                         id = fasta[0]["id"], name = fasta[0]["name"], description = fasta[0]["description"] )
+#         sr = SeqRecord(seq = fasta[0]["sequence"] + fasta[0]["sequence"][:int(circextend * length)], \
+#                         id = fasta[0]["id"], name = fasta[0]["name"], description = fasta[0]["description"])
 #
-#         fastafile = path + "/" + os.path.basename( orgfastafile ) + ".lin"
-#         f = open( fastafile, "w" )
-#         SeqIO.write( sr, f, "fasta" )
+#         fastafile = path + "/" + os.path.basename(orgfastafile) + ".lin"
+#         f = open(fastafile, "w")
+#         SeqIO.write(sr, f, "fasta")
 #         f.close()
 
     # create plot path
@@ -211,15 +209,15 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
     for a in "_".join(fasta[0]["name"].split()):
         if a.isalnum() or a == "_" or a == "-":
             acc.append(a)
-#        else:
-#            acc.append( "_" )
+        # else:
+        #    acc.append("_")
 
     if len(acc) == 0:
         acc = "noname"
     else:
         acc = "".join(acc)
 
-######    acc = "_".join( fasta[0]["name"].split() )
+    # acc = "_".join(fasta[0]["name"].split())
 
     if '|' in acc:
         raise Exception("No | character allowed in fasta header! Aborting")
@@ -229,7 +227,7 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
 
     # run RNA models in fast mode with strict threshold (if not sensitive mode only)
     # TODO get copy and part numbers for ncRNAs
-    if((trna or rrna or oril or intron) and not sensitive):
+    if (trna or rrna or oril or intron) and not sensitive:
         rnalist = mitfi.mitfi(fastafiles, offsets, mitfipath, code, refdir,
                               evalue=ncev, sensitive=False, length=length, gl=(
                                   not localonly),
@@ -246,8 +244,7 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
     if trna:
         cand[0]["tRNA"] = [
             x for x in rnalist if x.type == "tRNA" and x.mito == 2]
-        cand[1]["tRNA"] = [x for x in rnalist if x.type ==
-                           "tRNA" and x.mito == 1 and x.evalue <= 0.001]
+        cand[1]["tRNA"] = [x for x in rnalist if x.type == "tRNA" and x.mito == 1 and x.evalue <= 0.001]
         if plots:
             print_for_plotting(
                 cand[0]["tRNA"], cand[1]["tRNA"], "%s/plots/rna.dat" % (path), "global")
@@ -303,22 +300,21 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
                                     cutoff=cutoff,
                                     minevalue=minevalue, acc=acc, code=code, plot=plots,
                                     finovl=finovl, clipfac=clipfac, oldstst=oldstst)
-    #                     , ststrange = ststrange, maxdegenerate = maxdegenerate )
+    #                     , ststrange = ststrange, maxdegenerate = maxdegenerate)
 
         # compile the list of candidate sets
-        cand[0]["prot"] = [x for x in blastfeat if (x.type == "gene" and
-                                                    x.name in mito.metazoa_prot and
-                                                    (x.copy == None or x.copy == 0))]
-        cand[1]["prot"] = [x for x in blastfeat if (x.type == "gene" and
-                                                    x.name in mito.metazoa_prot and
-                                                    (x.copy != None and x.copy != 0))]
-
-        cand[0]["oprot"] = [x for x in blastfeat if (x.type == "gene" and
-                                                     x.name not in mito.metazoa_prot and
-                                                     (x.copy == None or x.copy == 0))]
-        cand[1]["oprot"] = [x for x in blastfeat if (x.type == "gene" and
-                                                     x.name not in mito.metazoa_prot and
-                                                     (x.copy != None and x.copy != 0))]
+        cand[0]["prot"] = [x for x in blastfeat if (x.type == "gene"
+                                                    and x.name in mito.metazoa_prot
+                                                    and (x.copy is None or x.copy == 0))]
+        cand[1]["prot"] = [x for x in blastfeat if (x.type == "gene"
+                                                    and x.name in mito.metazoa_prot
+                                                    and (x.copy is not None and x.copy != 0))]
+        cand[0]["oprot"] = [x for x in blastfeat if (x.type == "gene"
+                                                     and x.name not in mito.metazoa_prot
+                                                     and (x.copy is None or x.copy == 0))]
+        cand[1]["oprot"] = [x for x in blastfeat if (x.type == "gene"
+                                                     and x.name not in mito.metazoa_prot
+                                                     and (x.copy is not None and x.copy != 0))]
 
     if orih:
         blastfeat = blast.blast(fastafiles, offsets, False, orih, path,
@@ -330,11 +326,11 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
                                 cutoff=cutoff,
                                 minevalue=minevalue, acc=acc, code=code, plot=plots,
                                 finovl=finovl, clipfac=clipfac)
-#                     , ststrange = ststrange, maxdegenerate = maxdegenerate )
+#                     , ststrange = ststrange, maxdegenerate = maxdegenerate)
         cand[0]["OH"] = [x for x in blastfeat if (
-            x.type == "rep_origin" and (x.copy == None or x.copy == 0))]
+            x.type == "rep_origin" and (x.copy is None or x.copy == 0))]
         cand[1]["OH"] = [x for x in blastfeat if (
-            x.type == "rep_origin" and (x.copy != None and x.copy != 0))]
+            x.type == "rep_origin" and (x.copy is not None and x.copy != 0))]
 
     # sort the candidates accordingly
     for rnd in range(2):
@@ -363,10 +359,10 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
 
 #     # get default protein and rep-ori features for the two round (1st: best hit, 2nd the rest)
 #     if prot:
-#         protfeat = [x for x in blastfeat if ( x.type == "gene" and \
-#                                                ( x.copy == None or x.copy == 0 ) )]
-#         mprotfeat = [x for x in blastfeat if ( x.type == "gene" and \
-#                                                 ( x.copy != None and x.copy != 0 ) )]
+#         protfeat = [x for x in blastfeat if (x.type == "gene" and \
+#                                                (x.copy is None or x.copy == 0))]
+#         mprotfeat = [x for x in blastfeat if (x.type == "gene" and \
+#                                                 (x.copy is not None and x.copy != 0))]
 #     else:
 #         protfeat = []
 #         mprotfeat = []
@@ -377,7 +373,7 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
 #     if trna:
 #         trnafeat = [x for x in rnalist if x.type == "tRNA" and x.mito == 2]
 #         mtrnafeat = [x for x in rnalist if x.type == "tRNA" and x.mito == 1 and x.evalue <= 0.001]
-#         print_for_plotting( trnafeat, mtrnafeat, "%s/plots/rna.dat" % ( path ), "global" )
+#         print_for_plotting(trnafeat, mtrnafeat, "%s/plots/rna.dat" % (path), "global")
 #     else:
 #         trnafeat = []
 #         mtrnafeat = []
@@ -385,43 +381,43 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
 #     if rrna:
 #         rrnafeat = [x for x in rnalist if x.type == "rRNA" and x.mito == 2]
 #         mrrnafeat = [x for x in rnalist if x.type == "rRNA" and x.mito == 1]
-#         print_for_plotting( rrnafeat, mrrnafeat, "%s/plots/rna.dat" % ( path ), "global" )
+#         print_for_plotting(rrnafeat, mrrnafeat, "%s/plots/rna.dat" % (path), "global")
 #     else:
 #         rrnafeat = []
 #         mrrnafeat = []
 #
 #     if cr:
-#         crfeat = [x for x in blastfeat + rnalist if ( ( x.type == "rep_origin" )and \
-#                                                        ( x.method != "mitfi" or x.evalue <= 0.1 ) \
-#                                              and ( x.copy == None or x.copy == 0 ) )]
-#         mcrfeat = [x for x in blastfeat + rnalist if ( ( x.type == "rep_origin" ) and \
-#                                                        ( x.method != "mitfi" or x.evalue <= 0.1 ) \
-#                                               and ( x.copy != None and x.copy != 0 ) )]
+#         crfeat = [x for x in blastfeat + rnalist if ((x.type == "rep_origin")and \
+#                                                        (x.method != "mitfi" or x.evalue <= 0.1) \
+#                                              and (x.copy is None or x.copy == 0))]
+#         mcrfeat = [x for x in blastfeat + rnalist if ((x.type == "rep_origin") and \
+#                                                        (x.method != "mitfi" or x.evalue <= 0.1) \
+#                                               and (x.copy is not None and x.copy != 0))]
 #     else:
 #         crfeat = []
 #         mcrfeat = []
 #
-#     logging.debug( "PROT FEATURES CANDIDATES" )
+#     logging.debug("PROT FEATURES CANDIDATES")
 #     for f in protfeat:
-#         logging.debug( "%s" % str( f ) )
-#     logging.debug( "TRNA FEATURES CANDIDATES" )
+#         logging.debug("%s" % str(f))
+#     logging.debug("TRNA FEATURES CANDIDATES")
 #     for f in trnafeat:
-#         logging.debug( "{name} {strand} {start} {stop}".format( name = f.name, strand = f.strand, start = f.start, stop = f.stop ) )
-#     logging.debug( "RRNA FEATURES CAND" )
-#     for f in sorted( rrnafeat, key = lambda x:x.start ):
-#         logging.debug( "{name} {strand} {start} {stop}".format( name = f.name, strand = f.strand, start = f.start, stop = f.stop ) )
-#     logging.debug( "CR FEATURES CANDIDATES" )
-#     for f in sorted( crfeat, key = lambda x:x.start ):
-#         logging.debug( "{name} {strand} {start} {stop}".format( name = f.name, strand = f.strand, start = f.start, stop = f.stop ) )
-#     logging.debug( "MFEATURES CANDIDATES" )
+#         logging.debug("{name} {strand} {start} {stop}".format(name = f.name, strand = f.strand, start = f.start, stop = f.stop))
+#     logging.debug("RRNA FEATURES CAND")
+#     for f in sorted(rrnafeat, key = lambda x:x.start):
+#         logging.debug("{name} {strand} {start} {stop}".format(name = f.name, strand = f.strand, start = f.start, stop = f.stop))
+#     logging.debug("CR FEATURES CANDIDATES")
+#     for f in sorted(crfeat, key = lambda x:x.start):
+#         logging.debug("{name} {strand} {start} {stop}".format(name = f.name, strand = f.strand, start = f.start, stop = f.stop))
+#     logging.debug("MFEATURES CANDIDATES")
 #     for f in mprotfeat:
-#         logging.debug( "%s" % str( f ) )
-#     for f in sorted( mtrnafeat, key = lambda x:x.start ):
-#         logging.debug( "{name} {strand} {start} {stop}".format( name = f.name, strand = f.strand, start = f.start, stop = f.stop ) )
-#     for f in sorted( mrrnafeat, key = lambda x:x.start ):
-#         logging.debug( "{name} {strand} {start} {stop}".format( name = f.name, strand = f.strand, start = f.start, stop = f.stop ) )
-#     for f in sorted( mcrfeat, key = lambda x:x.start ):
-#         logging.debug( "{name} {strand} {start} {stop}".format( name = f.name, strand = f.strand, start = f.start, stop = f.stop ) )
+#         logging.debug("%s" % str(f))
+#     for f in sorted(mtrnafeat, key = lambda x:x.start):
+#         logging.debug("{name} {strand} {start} {stop}".format(name = f.name, strand = f.strand, start = f.start, stop = f.stop))
+#     for f in sorted(mrrnafeat, key = lambda x:x.start):
+#         logging.debug("{name} {strand} {start} {stop}".format(name = f.name, strand = f.strand, start = f.start, stop = f.stop))
+#     for f in sorted(mcrfeat, key = lambda x:x.start):
+#         logging.debug("{name} {strand} {start} {stop}".format(name = f.name, strand = f.strand, start = f.start, stop = f.stop))
 #
 # #     print "ALL FEATURES CAND"
 # #     for f in [x for x in rnalist]:
@@ -430,17 +426,17 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
 #     # sort the features such that the best are first in the list
 #     # then the featureappend function will remove the worse of duplicates
 #     # that are due to the handling of circularity
-#     protfeat.sort( key = lambda x:x.score, reverse = True )
-#     crfeat.sort( key = lambda x:x.score, reverse = True )
-#     trnafeat.sort( key = lambda x:x.evalue )
-#     rrnafeat.sort( key = lambda x:x.evalue )
+#     protfeat.sort(key = lambda x:x.score, reverse = True)
+#     crfeat.sort(key = lambda x:x.score, reverse = True)
+#     trnafeat.sort(key = lambda x:x.evalue)
+#     rrnafeat.sort(key = lambda x:x.evalue)
 #
 #     # set features: 1st round
 #     featurelist = []
-#     featureappend( protfeat, featurelist, circular, length, overlap = finovl )
-#     featureappend( trnafeat, featurelist, circular, length, overlap = finovl )
-#     featureappend( rrnafeat, featurelist, circular, length, overlap = finovl, rnd = True )
-#     featureappend( crfeat, featurelist, circular, length, overlap = finovl )
+#     featureappend(protfeat, featurelist, circular, length, overlap = finovl)
+#     featureappend(trnafeat, featurelist, circular, length, overlap = finovl)
+#     featureappend(rrnafeat, featurelist, circular, length, overlap = finovl, rnd = True)
+#     featureappend(crfeat, featurelist, circular, length, overlap = finovl)
 
     logging.debug("State after first round")
     for f in featurelist:
@@ -484,8 +480,8 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
                 # get a conflict free set of mito>0 features of name lname
                 localhits = []
                 nlocalhits = []
-                featureappend([x for x in lrnalist if x.mito > 0 and x.name ==
-                               lname], localhits, nlocalhits, circular, length, overlap=finovl)
+                featureappend([x for x in lrnalist if x.mito > 0 and x.name == lname],
+                              localhits, nlocalhits, circular, length, overlap=finovl)
 
                 if plots:
                     print_for_plotting(
@@ -494,7 +490,7 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
                 # append the local features
                 featureappend(
                     localhits, featurelist, nfeaturelist, circular, length, overlap=finovl)
-#                 appendlocalfeature( localhits, lname, cand[0]["rRNA"], featurelist, length, allowoverlap = finovl )
+#                 appendlocalfeature(localhits, lname, cand[0]["rRNA"], featurelist, length, allowoverlap = finovl)
 
     if not best:
         logging.debug("annotate weaker hits")
@@ -535,10 +531,10 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
 
 #         for feat in mrrnafeat + mtrnafeat:
 #             besthit = [x for x in featurelist if x.name == feat.name]
-#             if len( besthit ) == 0:
+#             if len(besthit) == 0:
 #                 maxevalue = 1
 #             else:
-#                 besthit.sort( key = lambda x:( -x.mito, x.evalue ) )
+#                 besthit.sort(key = lambda x:(-x.mito, x.evalue))
 #                 maxevalue = besthit[0].evalue
 #             if maxevalue == 0:
 #                 maxevalue = 1E-46
@@ -546,19 +542,19 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
 #
 #         for feat in mprotfeat + mcrfeat:
 #             besthit = [x for x in featurelist if x.name == feat.name]
-#             if len( besthit ) == 0:
+#             if len(besthit) == 0:
 #                 maxscore = 1
 #             else:
-#                 besthit.sort( key = lambda x:x.score )
+#                 besthit.sort(key = lambda x:x.score)
 #                 maxscore = besthit[0].score
 #             if maxscore == 0:
 #                 maxscore = 1E46
-#             feat.evalfaktor = 1 / ( feat.score / maxscore )
+#             feat.evalfaktor = 1 / (feat.score / maxscore)
 #
 #         dolist = mrrnafeat + mtrnafeat + mprotfeat + mcrfeat
-#         dolist.sort( key = lambda x:x.evalfaktor )
+#         dolist.sort(key = lambda x:x.evalfaktor)
 #
-#         featureappend( dolist, featurelist, circular, length, overlap = finovl )
+#         featureappend(dolist, featurelist, circular, length, overlap = finovl)
 
     # check if
     # - local features are too short -> remove
@@ -567,35 +563,35 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
         localcheck, featurelist, sequence, refdir, circular, length)
 
     # determine final copy part numbers (also for ncRNAs)
-    cpyprt = _copy_part(featurelist, fragovl, fragfac)
+    _copy_part(featurelist, fragovl, fragfac)
 
 #     # - apply start and stop prediction to the 1st and last parts
 #     if prot:
-#         ststf = open( "%s/blast/stst.dat" % ( path ), "w" )
+#         ststf = open("%s/blast/stst.dat" % (path), "w")
 #         for n in cpyprt:
 #             for cpy in cpyprt[n]:
 #                 if cpyprt[n][cpy][0].type != "gene":
 #                     continue
-#                 plotdat = blast._improve_start_stop( cpyprt[n][cpy],
+#                 plotdat = blast._improve_start_stop(cpyprt[n][cpy],
 #                                     'e', False, False, sequence,
 #                                     code, stacod, stocod, len_pval,
 #                                     blastidx[n], blastvalues, cpyprt, featurelist,
-#                                     circular )
-#                 ststf.write( plotdat )
+#                                     circular)
+#                 ststf.write(plotdat)
 #         ststf.close()
-# #         _improve_start_stop_old( cpyprt[n][cpy], code, sequence, length, ststrange, idx[n], values, scoresel, havg, pavg )
+# #         _improve_start_stop_old(cpyprt[n][cpy], code, sequence, length, ststrange, idx[n], values, scoresel, havg, pavg)
 #
 #     # START STOP PREDICTION CREATES MORE THAT FINOVL OVERLAPS
 #     # -> remove
-#     for i in xrange( len( featurelist ) ):
-#         if featurelist[i] == None or featurelist[i].type != "gene":
+#     for i in xrange(len(featurelist)):
+#         if featurelist[i] is None or featurelist[i].type != "gene":
 #             continue
 #
-#         for j in xrange( len( featurelist ) ):
-#             if featurelist[j] == None or featurelist[j].type != "gene" or i == j:
+#         for j in xrange(len(featurelist)):
+#             if featurelist[j] is None or featurelist[j].type != "gene" or i == j:
 #                 continue
 #
-#             cap = feature.cap( featurelist[i].start, featurelist[i].stop, featurelist[j].start, featurelist[j].stop, circular, len( sequence ) )
+#             cap = feature.cap(featurelist[i].start, featurelist[i].stop, featurelist[j].start, featurelist[j].stop, circular, len(sequence))
 #
 #             if cap <= finovl:
 #                 continue
@@ -607,14 +603,14 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
 #
 #             break
 
-    featurelist = [x for x in featurelist if x != None]
+    featurelist = [x for x in featurelist if x is not None]
 
     # remove features from nfeaturelist that appear as well in featurelist
     nfeaturelist = [x for x in nfeaturelist if x not in featurelist]
 #     i = 0
-#     while i < len( nfeaturelist ):
+#     while i < len(nfeaturelist):
 #         d = False
-#         for j in xrange( len( featurelist ) ):
+#         for j in xrange(len(featurelist)):
 #             if nfeaturelist[i] == featurelist[j]:
 #                 d = True
 #                 break
@@ -639,7 +635,7 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
                "%d" % (len(sequence))]
         logging.debug(" ".join(cmd))
         p = subprocess.Popen(
-            cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True)
         ret = p.wait()
         if ret != 0:
             stdout, stderr = p.communicate()
@@ -651,7 +647,7 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
                "%s/plots/" % (path)]
         logging.debug(" ".join(cmd))
         p = subprocess.Popen(
-            cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True)
         ret = p.wait()
         if ret != 0:
             stdout, stderr = p.communicate()
@@ -665,7 +661,7 @@ def mitos(fastafile, code, ncbicode, best, order, alarab=False,
                "%s/plots/rna.pdf" % (path)]
         logging.debug(" ".join(cmd))
         p = subprocess.Popen(
-            cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True)
         ret = p.wait()
         if ret != 0:
             stdout, stderr = p.communicate()
@@ -820,7 +816,7 @@ def problems(prot, ctrna, rrna, cr, features, circular, sequence, code):
                 else:
                     texc[-1].append(None)
 
-            if len(texc) > 0 and texc[-1][1] == None and texc[-1][2] == None:
+            if len(texc) > 0 and texc[-1][1] is None and texc[-1][2] is None:
                 del texc[-1]
 
     mis = _Counter(mis)
@@ -842,7 +838,7 @@ def _Counter(lst):
     """
     count number of occurences of items in a list and return as dict
     @param lst a list
-    @return dict linking list items to number of occurences 
+    @return dict linking list items to number of occurences
 
     note this is idendical to collections.Counter (which was introduced with python 2.7)
     """
@@ -915,8 +911,8 @@ if __name__ == '__main__':
 # default=0.2, help="allow overlap up to a fraction of FRACTION ")
     group.add_argument("--clipfac", action="store", type=float, metavar="FACTOR", default=10,
                        help="overlapping features of the same name differing by at most a factor of FACTOR are clipped")
-#     group.add_argument( "--ststrange", action = "store", type = "int", metavar = "NRAA", default = 6, help = "search the perimeter of start and stop positions by NRAA aminocids for better values" )
-#     group.add_argument( "--maxdeg", action = "store", type = "int", metavar = "NRNT", default = 2, help = "maximum number of missing nt for incomplete stop" )
+#     group.add_argument("--ststrange", action = "store", type = "int", metavar = "NRAA", default = 6, help = "search the perimeter of start and stop positions by NRAA aminocids for better values")
+#     group.add_argument("--maxdeg", action = "store", type = "int", metavar = "NRNT", default = 2, help = "maximum number of missing nt for incomplete stop")
     group.add_argument("--ncbicode", action="store_true", default=False,
                        help="use start/stop codons as in NCBI (default: learned start/stop codons)")
 
@@ -981,7 +977,7 @@ if __name__ == '__main__':
     if not os.path.isdir(args.outdir):
         parser.error("no such directory %s" % args.outdir)
 
-    if args.code == None:
+    if args.code is None:
         parser.error("no genetic code given")
 
     if args.alarab and not os.path.isdir(os.path.join(refdir, "featureProtHMM")):
@@ -999,7 +995,7 @@ if __name__ == '__main__':
         x for x in sorted(orderdict, key=orderdict.get) if orderdict[x] > 0]
 
     # get sequences from file / fasta
-    if args.file != None:
+    if args.file is not None:
         fh = open(args.file)
     else:
         fh = io.StringIO(args.fasta)
@@ -1018,6 +1014,10 @@ if __name__ == '__main__':
         acc = sequences[i]["id"]
 
         # create temporaty sequence file in output dir
+
+        for d in ["id", "name", "description"]:
+            sequences[i][d] = re.sub('[()?|\t]', '_', sequences[i][d])
+
         tmpf = open("%s/sequence.fas" % odir, "w")
         sr = SeqRecord(seq=sequences[i]["sequence"], id=sequences[i]["id"],
                        name=sequences[i]["name"], description=sequences[i]["description"])
@@ -1030,7 +1030,7 @@ if __name__ == '__main__':
                             finovl=args.finovl,
                             clipfac=args.clipfac, fragovl=args.fragovl,
                             fragfac=args.fragfac,
-                            # prot = args.noprot, trna = args.notrna, rrna = args.norrna, cr = args.noorig\
+                            # prot=args.noprot, trna=args.notrna, rrna=args.norrna, cr=args.noorig\
                             sensitive=args.sensitive, localonly=args.localonly,
                             refdir=refdir,
                             ncev=args.ncev,
@@ -1041,10 +1041,10 @@ if __name__ == '__main__':
 
         bedfile.bedwriter(featurelist, acc, outfile="%s/result.bed" % odir)
         sequin.sequinwriter(featurelist, acc, outfile="%s/result.seq" % odir)
-        gfffile.gffwriter(featurelist, acc, outfile = "%s/result.gff" % odir, mode = "w")
-        feature.genorderwriter( featurelist, acc, "%s/result.geneorder" % odir)
-        fastawriter( featurelist, sequences[i]["sequence"], None, acc, "fas", outfile = "%s/result.fas" % odir)
-        fastawriter( featurelist, sequences[i]["sequence"], args.code, acc, "faa", outfile = "%s/result.faa" % odir)
+        gfffile.gffwriter(featurelist, acc, outfile="%s/result.gff" % odir, mode="w")
+        feature.genorderwriter(featurelist, acc, "%s/result.geneorder" % odir)
+        fastawriter(featurelist, sequences[i]["sequence"], None, acc, "fas", outfile="%s/result.fas" % odir)
+        fastawriter(featurelist, sequences[i]["sequence"], args.code, acc, "faa", outfile="%s/result.faa" % odir)
 
         # parse fasta header
         sequence = sequences[i]["sequence"]
@@ -1053,17 +1053,17 @@ if __name__ == '__main__':
         istop = problems_internal_stops(featurelist, sequence, args.code)
         if len(mis) > 0:
             sys.stdout.write("missing:")
-            for key, value in mis.items():
+            for key, value in list(mis.items()):
                 sys.stdout.write("%s " % (key))
             sys.stdout.write("\n")
         if len(dup) > 0:
             sys.stdout.write("duplicated:")
-            for key, value in dup.items():
+            for key, value in list(dup.items()):
                 sys.stdout.write("%dx %s " % (value, key))
             sys.stdout.write("\n")
         if len(nst) > 0:
             sys.stdout.write("non standard:")
-            for key, value in nst.items():
+            for key, value in list(nst.items()):
                 sys.stdout.write("%dx %s " % (value, key))
             sys.stdout.write("\n")
         if len(texc) > 0:
@@ -1079,6 +1079,6 @@ if __name__ == '__main__':
         os.remove("%s/sequence.fas" % odir)
 
 
-#     pkl = open( "%s/result.pkl" % args.outdir, "w" )
-#     cPickle.dump( featurelist, pkl )
+#     pkl = open("%s/result.pkl" % args.outdir, "w")
+#     cPickle.dump(featurelist, pkl)
 #     pkl.close()
